
import React, { useState, useEffect } from 'react';
import { createRoot } from 'react-dom/client';
import jsPDF from 'jspdf';
import html2canvas from 'html2canvas';

interface Course {
  id: number;
  title: string;
  description: string;
}

interface CourseWithState extends Course {
  progress: number;
  status: 'locked' | 'unlocked' | 'completed';
}

interface CourseTopic {
  id: string;
  title: string;
  status: 'locked' | 'unlocked' | 'completed';
}


const initialCourses: Course[] = [
    { 
        id: 1, 
        title: 'Course 1: Digital Marketing',
        description: 'You will learn how to promote and sell products online using ICT tools like social media and design apps.'
    },
    {
        id: 2,
        title: 'Course 2: Responsible Use of ICT',
        description: 'Learn how to be a safe, ethical, and responsible digital citizen. This course covers online safety, netiquette, and protecting your digital footprint.'
    },
    {
        id: 3,
        title: 'Course 3: Legal & Ethical ICT Use',
        description: 'Understand the laws and ethics governing technology, including copyright, data privacy, and cybercrime.'
    },
    {
        id: 4,
        title: 'Course 4: Tools and Equipment in ICT',
        description: 'This course introduces the essential hardware and software tools used in Information and Communications Technology (ICT). Students will learn the tools in computer servicing, programming, visual arts, and telecommunications tasks.'
    },
    {
        id: 5,
        title: 'Course 5: Software Applications',
        description: "Understand the two main types of software—application and system software—how they function, and how they work together to help users perform tasks."
    },
    {
        id: 6,
        title: 'Course 6: Graphic Design Software',
        description: 'Explore the world of graphic design with hands-on experience using popular software. Learn about raster and vector graphics, design principles, and create your own visual content.'
    },
    {
        id: 7,
        title: 'Course 7: Video Editing',
        description: 'Master the art of video editing. Learn to cut, arrange, and enhance video clips to create compelling stories. This course covers fundamental techniques and introduces popular editing software.'
    }
];

const initialCourse4Topics: CourseTopic[] = [
  { id: 'programming', title: 'Course 4.1 Tools and Equipment in Computer Programming', status: 'unlocked' },
  { id: 'visual_arts', title: 'Course 4.2 Tools and Equipment in Computer Visual Arts', status: 'locked' },
  { id: 'servicing', title: 'Course 4.3 Tools and Equipment in Computer System Servicing', status: 'locked' },
  { id: 'telecom', title: 'Course 4.4 Tools and Equipment in Telecommunications', status: 'locked' }
];

const unlockCodes: { [key: number]: string } = {
    1: '1forall',
    2: '303991c2',
    3: 'guin3',
    4: 'go4it',
    5: '12345',
    6: 'fix6',
    7: '7wonders',
};

const course1Content = (VideoLink: React.ComponentType<{href: string, children: React.ReactNode}>) => ({
    part1: (
        <>
            <h4>What is Digital Marketing?</h4>
            <p>Digital marketing is the use of information and communication technologies (ICT)—such as the internet, smartphones, apps, and digital media—to promote, sell, and distribute products or services. Unlike traditional marketing, which relies on printed posters, flyers, or face-to-face promotions, digital marketing allows sellers to reach more people faster and at a lower cost, all with the help of technology.</p>
            <p>Watch the video about Digital Marketing: <VideoLink href="https://www.youtube.com/watch?v=aC-DwwgqG6A">https://www.youtube.com/watch?v=aC-DwwgqG6A</VideoLink></p>
        </>
    ),
    part2: (
        <>
            <h4>ICT in Action: How It Powers Online Marketing</h4>
            <p>ICT plays a vital role in every step of digital marketing. It helps businesses and individuals:</p>
            <ol>
                <li><strong>Create content</strong> – using design tools like Canva, video editors like CapCut, or photography apps to produce product images, logos, or promotional videos.</li>
                <li><strong>Communicate with customers</strong> – through social media, messaging apps (like Facebook Messenger, Viber, WhatsApp), and email to answer inquiries or send updates.</li>
                <li><strong>Promote products</strong> – on platforms like Facebook, Instagram, TikTok, and Shopee using posts, reels, paid ads, or influencer collaborations.</li>
                <li><strong>Sell and collect payment</strong> – through online stores and payment apps like GCash, Maya, or bank transfers.</li>
                <li><strong>Deliver products</strong> – with the help of apps like Lalamove, J&T Express, and LBC for local and national deliveries.</li>
            </ol>
            <p>All of this is possible with tools that many students and small businesses already have access to, such as a smartphone, internet connection, and free digital apps.</p>
            <p>Watch the video about AI Tools in Digital Marketing: <VideoLink href="https://www.youtube.com/watch?v=nkuPUJVzB_E">https://www.youtube.com/watch?v=nkuPUJVzB_E</VideoLink></p>
        </>
    ),
    part3: (
        <>
            <h4>Online Selling by Students</h4>
            <p>Let’s say a Grade 8 student named Liza wants to sell handmade scrunchies. She can use her phone to take attractive photos of the products, edit them in Canva, and post them on Facebook Marketplace or TikTok. She can chat with interested buyers via Messenger, receive payments through GCash, and send the scrunchies via J&T Express. Through this, Liza is using ICT for marketing—without needing a physical store or expensive equipment.</p>
            <hr className="content-divider" />
            <h4>🎯 📌 Why Is This Important?</h4>
            <p>In today’s highly connected world, Information and Communication Technology (ICT) is more than just a set of digital tools—it is a gateway to entrepreneurial success, especially for students. Learning how to use ICT for online marketing equips young learners with skills that are relevant, practical, and empowering.</p>
            <p>First, it builds entrepreneurial skills. With just a smartphone and internet access, students can already start small online businesses. They learn how to sell products, manage orders, interact with customers, and build a brand. This early exposure to entrepreneurship allows them to experience the real-world challenges and benefits of running a business.</p>
            <p>Second, it develops digital literacy. Students become familiar with various online platforms—social media, content creation tools, e-commerce sites, and mobile wallets. They learn to navigate these responsibly, recognizing the importance of ethical conduct, data privacy, and online etiquette.</p>
            <p>Third, it strengthens creativity and communication skills. Creating promotional posters in Canva or editing videos on CapCut teaches students how to design attractive content. Writing compelling captions and engaging with customers on chat apps hones their ability to communicate effectively and persuasively.</p>
            <p>Lastly, it enhances problem-solving skills. From resolving delivery issues to handling customer complaints and updating online listings, students are challenged to think critically and adapt quickly. These experiences train them to make decisions, find solutions, and improve continuously.</p>
            <p>Even if students don’t run a real business, practicing these skills in simulations and projects helps prepare them for careers in marketing, business, communication, or freelancing.</p>
            <hr className="content-divider" />
            <h4>📘 Summary</h4>
            <p>In the digital age, ICT is an essential tool for online marketing. It empowers individuals—including students—to reach a wider audience, promote products creatively, communicate efficiently, and run businesses with minimal cost. Through ICT, digital marketing becomes an accessible and practical skill that supports entrepreneurship, creativity, and real-world readiness. By learning this topic, students not only understand the role of technology in business but also discover how they can become responsible and capable digital entrepreneurs.</p>
        </>
    )
});

const courseDiscussions: { [key: number]: React.ReactNode } = {
    1: <></>, // Course 1 content is handled specially
    2: (
    <div className="course-discussion-content">
        <h4>WHAT IS DIGITAL CITIZENSHIP?</h4>
        <p>Digital Citizenship is about how we behave online — how we act, talk, share, and protect ourselves and others while using the internet or any digital device.</p>
        <p>It means:</p>
        <ul>
            <li>Being safe (not putting yourself at risk online),</li>
            <li>Being respectful (treating others kindly and fairly),</li>
            <li>Being smart (making good choices with technology),</li>
            <li>And being responsible (knowing your rights and duties online).</li>
        </ul>
        <p>Just like being a good citizen in your town or school, being a good digital citizen helps build a better, safer online community.</p>

        <hr className="content-divider" />

        <h4>🧩 9 ELEMENTS OF DIGITAL CITIZENSHIP (With Deep Explanation)</h4>
        <ol>
            <li>
                <h5>1. Digital Access</h5>
                <p>🔑 <em>“Everyone should have equal opportunities to use technology and the internet.”</em></p>
                <p><strong>What it means:</strong> Not everyone in the world (or even in one classroom) has the same internet access. Good digital citizens help bridge this gap.</p>
                <p><strong>Why it matters:</strong> Fair access helps all students learn and grow equally.</p>
                <p><strong>Example:</strong> A school making sure that students without internet at home can borrow Wi-Fi devices or use the computer lab.</p>
            </li>
            <li>
                <h5>2. Digital Commerce</h5>
                <p>💸 <em>“Buying and selling goods or services safely online.”</em></p>
                <p><strong>What it means:</strong> Many people shop online now. This includes buying clothes, books, games, or even ordering food.</p>
                <p><strong>Why it matters:</strong> Students must know how to recognize safe websites, avoid scams, and protect their payment info.</p>
                <p><strong>Example:</strong> A secure website begins with "https" and often shows a lock icon 🔒 in the address bar.</p>
            </li>
            <li>
                <h5>3. Digital Communication</h5>
                <p>📨 <em>“Exchanging information through digital tools in a respectful way.”</em></p>
                <p><strong>What it means:</strong> We talk and share through emails, texts, social media, and video calls.</p>
                <p><strong>Why it matters:</strong> The way we communicate online reflects our character. Words typed in anger or shared publicly can hurt others or cause trouble.</p>
                <p><strong>Example:</strong> Sending a polite email to your teacher or replying kindly in a group chat.</p>
            </li>
            <li>
                <h5>4. Digital Literacy</h5>
                <p>📚 <em>“Knowing how to use technology and understand online information.”</em></p>
                <p><strong>What it means:</strong> It’s more than just using gadgets — it's about knowing how to use them wisely.</p>
                <p><strong>Why it matters:</strong> There’s a lot of fake news and unreliable content online. You must know how to find the truth.</p>
                <p><strong>Example:</strong> Knowing how to use Google for research, checking sources, and recognizing fake news.</p>
            </li>
            <li>
                <h5>5. Digital Etiquette</h5>
                <p>🤝 <em>“Being polite and respectful in digital spaces.”</em></p>
                <p><strong>What it means:</strong> Online manners matter! People can’t see your facial expressions or hear your tone — so it’s easy to misunderstand messages.</p>
                <p><strong>Why it matters:</strong> Bad digital behavior like trolling, spamming, or cyberbullying causes harm.</p>
                <p><strong>Example:</strong> Not using ALL CAPS (which sounds like shouting) and avoiding rude comments.</p>
            </li>
            <li>
                <h5>6. Digital Law</h5>
                <p>⚖️ <em>“Understanding what is legal and illegal in the digital world.”</em></p>
                <p><strong>What it means:</strong> There are rules online, just like in real life. You can’t take other people’s work or break rules just because you’re behind a screen.</p>
                <p><strong>Why it matters:</strong> Breaking digital laws can lead to punishment or even jail.</p>
                <p><strong>Example:</strong> Copying a classmate’s project or downloading a pirated movie is illegal and dishonest.</p>
            </li>
            <li>
                <h5>7. Digital Rights and Responsibilities</h5>
                <p>🗳️ <em>“You have rights online — but also responsibilities.”</em></p>
                <p><strong>What it means:</strong> You have the right to privacy, freedom of speech, and safety online. But with those rights come responsibilities like using your voice wisely and protecting others.</p>
                <p><strong>Why it matters:</strong> The internet should be a safe space for everyone.</p>
                <p><strong>Example:</strong> Reporting harmful content or cyberbullying, not just ignoring it.</p>
            </li>
            <li>
                <h5>8. Digital Health and Wellness</h5>
                <p>🧠 <em>“Taking care of your body and mind when using technology.”</em></p>
                <p><strong>What it means:</strong> Too much screen time can cause headaches, eye strain, poor sleep, and stress.</p>
                <p><strong>Why it matters:</strong> Your health is more important than likes or followers.</p>
                <p><strong>Example:</strong> Taking breaks from screens every 30–60 minutes, sitting properly, and avoiding using your phone late at night.</p>
            </li>
            <li>
                <h5>9. Digital Security (Self-Protection)</h5>
                <p>🔒 <em>“Keeping your personal information and devices safe.”</em></p>
                <p><strong>What it means:</strong> Just like you lock your house, you must lock your digital life.</p>
                <p><strong>Why it matters:</strong> Hackers, viruses, and scammers can steal your data.</p>
                <p><strong>Example:</strong> Using strong passwords, turning on two-factor authentication, and not clicking suspicious links.</p>
            </li>
        </ol>

        <hr className="content-divider" />

        <h4>👣 DIGITAL FOOTPRINTS & IDENTITY</h4>
        <h5>👣 What is a Digital Footprint?</h5>
        <p>Your digital footprint is all the information you leave behind when you use the internet. It’s like your online shadow.</p>

        <h5>🔵 Two Types of Digital Footprints:</h5>
        <p><strong>Active Footprint</strong> – What you post or share on purpose.</p>
        <p><em>Example: Uploading a selfie, commenting on a video, or posting on Instagram.</em></p>
        <p><strong>Passive Footprint</strong> – What is collected about you without you noticing.</p>
        <p><em>Example: A website tracking how long you stayed, or a game app knowing your location.</em></p>

        <h5>🧑‍💻 What is Digital Identity?</h5>
        <p>Your digital identity is the image or reputation you build online through your digital footprint.</p>
        <p>It’s made up of:</p>
        <ul>
            <li>Your posts</li>
            <li>Your photos</li>
            <li>Your comments</li>
            <li>Your username</li>
            <li>Even your style of writing online</li>
        </ul>
        <p>Your digital identity can be positive or negative, and it can affect your future.</p>

        <h5>📌 Why Are They Important?</h5>
        <ol>
            <li><strong>💬 They Affect How People See You</strong>
            <p>Your future classmates, teachers, or even employers might search your name online. What will they find?</p>
            </li>
            <li><strong>🔍 They Can Be Permanent</strong>
            <p>Even if you delete a post, someone may have already screenshotted it. It may still exist online.</p>
            </li>
            <li><strong>🛡️ They Can Affect Your Safety</strong>
            <p>If you post too much personal information (like your birthday, home address, or school), strangers can use that against you.</p>
            </li>
            <li><strong>📣 They Give You a Voice</strong>
            <p>Use your online presence to spread kindness, raise awareness, or help others. That’s a powerful and positive identity!</p>
            </li>
        </ol>

        <hr className="content-divider" />

        <h4>🧠 TIPS TO MANAGE YOUR DIGITAL FOOTPRINT</h4>
        <table className="styled-table">
            <thead>
                <tr>
                    <th>DO</th>
                    <th>DON’T</th>
                </tr>
            </thead>
            <tbody>
                <tr><td>Think before you post</td><td>Share personal info (like address or phone number)</td></tr>
                <tr><td>Use respectful language online</td><td>Bully or make fun of others</td></tr>
                <tr><td>Use private settings on social media</td><td>Accept friend requests from strangers</td></tr>
                <tr><td>Report bad behavior or harmful content</td><td>Click on links you don’t trust</td></tr>
                <tr><td>Use strong passwords</td><td>Use the same password for everything</td></tr>
            </tbody>
        </table>

        <hr className="content-divider" />

        <h4>📚 WRAP-UP: BEING A RESPONSIBLE DIGITAL CITIZEN</h4>
        <p>Being a digital citizen means:</p>
        <ul>
            <li>✅ Using technology wisely</li>
            <li>✅ Being kind and respectful</li>
            <li>✅ Protecting your identity</li>
            <li>✅ Keeping yourself and others safe</li>
            <li>✅ Knowing your rights and following the rules</li>
        </ul>
    </div>
  ),
  3: (
    <div className="course-discussion-content">
        <h4>Republic Act No. 10844 – Establishment of the DICT (Sections 4, 5, and 6)</h4>
        <hr className="content-divider" />
        <h5>✅ What is ICT?</h5>
        <p>ICT stands for Information and Communications Technology. It includes all the tools we use to:</p>
        <ul><li>Talk with others (like messaging, calls, email),</li><li>Create and share information (like documents, videos, and photos),</li><li>Use the internet (websites, apps, online learning).</li></ul>
        <p>Today, we use ICT in school, at home, in offices, and even in government.</p>
        <hr className="content-divider" />
        <h5>🇵🇭 Why Does ICT Need a Law in the Philippines?</h5>
        <p>ICT is very powerful. It can:</p>
        <ul><li>Help people learn,</li><li>Connect the world,</li><li>Make work easier,</li><li>But it can also be misused.</li></ul>
        <p>That’s why the Philippine government created a law to guide, organize, and protect the use of ICT in the country.</p>
        <hr className="content-divider" />
        <h5>📘 Republic Act No. 10844</h5>
        <p>💡 <strong>Also called:</strong> "An Act Creating the Department of Information and Communications Technology (DICT)"</p>
        <p><strong>Passed on:</strong> May 23, 2016</p>
        <p>💬 <strong>What is the DICT?</strong></p>
        <p>The Department of Information and Communications Technology (DICT) is a national government agency. It is responsible for:</p>
        <ul><li>Planning and developing ICT in the country,</li><li>Making internet access better and safer,</li><li>Helping schools, businesses, and communities go digital,</li><li>Ensuring online safety and security.</li></ul>
        <hr className="content-divider" />
        <h5>🔍 Let’s Understand Sections 4, 5, and 6</h5>
        <h5>📌 SECTION 4 – Mandate of the DICT</h5>
        <p>This section explains the job or "mission" of the DICT. In simple terms: DICT’s job is to:</p>
        <ul><li>Make ICT systems in the Philippines better and more efficient,</li><li>Provide affordable internet access for all (especially in far places),</li><li>Help Filipinos learn and use digital tools,</li><li>Support cybersecurity (keeping people safe online),</li><li>Improve government services using ICT (like applying online for permits or IDs).</li></ul>
        <div className="example-box"><p>🧠 <strong>Example for Grade 8 students:</strong> Thanks to DICT, students can access free Wi-Fi in schools, and teachers are supported in using online learning platforms like LMS (Learning Management Systems).</p></div>
        <h5>📌 SECTION 5 – Powers and Functions of the DICT</h5>
        <p>This section talks about what the DICT can do to complete its mission. The DICT is allowed to:</p>
        <ul><li>Plan and create ICT projects across the country,</li><li>Set rules and guidelines for internet providers and IT companies,</li><li>Train people in using computers, software, and networks,</li><li>Lead programs for safe internet use,</li><li>Support schools and local government units (LGUs) with digital resources,</li><li>Promote the use of cloud computing, e-governance, and cybersecurity.</li></ul>
        <div className="example-box"><p>🧠 <strong>Example for students:</strong> If your school starts using an online system for enrollment or grading, DICT helps make that happen safely and effectively.</p></div>
        <h5>📌 SECTION 6 – Composition of the DICT</h5>
        <p>This section describes who works in the DICT and how it is organized. The DICT is led by:</p>
        <ul><li>A Secretary (like the captain of the team),</li><li>Three Undersecretaries (they help manage different parts of ICT),</li><li>Four Assistant Secretaries (they focus on smaller but important tasks like training, cybersecurity, etc.).</li></ul>
        <div className="example-box"><p>🧠 <strong>Easy idea to remember:</strong> Think of DICT like a school, where:</p><ul><li>The Secretary is the principal,</li><li>The Undersecretaries are the vice-principals,</li><li>The Assistant Secretaries are the department heads (for technology, safety, training, etc.).</li></ul><p>This team works together to plan and improve ICT systems across the country.</p></div>
        <hr className="content-divider" />
        <h5>🧠 Why Should Grade 8 Students Care?</h5>
        <ul><li>You use technology every day — DICT makes sure it works better.</li><li>The DICT helps make Wi-Fi available in schools and communities.</li><li>DICT protects your data and helps stop cyberbullying, hacking, and online crimes.</li><li>They support teachers in making lessons digital and fun.</li><li>As future professionals, you’ll benefit from job opportunities in ICT.</li></ul>
        <hr className="content-divider" />
        <h5>🎓 Summary Chart</h5>
        <table className="styled-table"><thead><tr><th>Section</th><th>Title</th><th>Key Idea</th></tr></thead><tbody><tr><td>Section 4</td><td>Mandate of DICT</td><td>What DICT is supposed to do (mission & goals)</td></tr><tr><td>Section 5</td><td>Powers and Functions</td><td>What DICT is allowed to do (authority & tasks)</td></tr><tr><td>Section 6</td><td>Composition</td><td>Who works at DICT and how it's organized</td></tr></tbody></table>

        <h4 style={{marginTop: '3rem', paddingTop: '2rem', borderTop: '1px solid #444'}}>Republic Act No. 10627 – The Anti-Bullying Act of 2013 (Section 2-D: Cyberbullying)</h4>
        <hr className="content-divider" />
        <h5>🧾 What is Republic Act No. 10627?</h5>
        <p>This law was passed to protect all students in elementary and high school from bullying of any kind. It recognizes that bullying doesn’t only happen in classrooms or hallways anymore — it can now happen online, anytime, and sometimes without the victim even knowing who the bully is.</p>
        <p>This law covers all forms of bullying, including:</p>
        <ul><li>Physical bullying (hurting someone’s body)</li><li>Verbal bullying (name-calling, teasing)</li><li>Social bullying (excluding someone on purpose)</li><li>And cyberbullying, which is discussed in Section 2-D.</li></ul>
        <hr className="content-divider" />
        <h5>📖 Section 2-D: Defining Cyberbullying</h5>
        <p><em>"Cyberbullying is any bullying done through the use of technology or any electronic means."</em></p>
        <p>This means:</p>
        <ul><li>Bullying using gadgets, computers, tablets, cellphones</li><li>Done through social media platforms like Facebook, TikTok, Instagram</li><li>Can happen in group chats, online games, emails, or websites</li></ul>
        <p>👉 What makes cyberbullying more dangerous?</p>
        <ul><li>It can happen 24/7</li><li>It can reach a lot of people fast</li><li>The bully can be anonymous or use a fake account</li><li>The message or post can be hard to delete once shared</li></ul>
        <hr className="content-divider" />
        <h5>📌 Forms of Cyberbullying (Explained One by One)</h5>
        <ol><li><strong>Hurtful Messages</strong><p>Sending mean, insulting, or threatening messages repeatedly.</p><p>📱 <em>Example: "You’re so dumb. You should just quit school."</em></p></li><li><strong>Spreading Rumors Online</strong><p>Making up lies about someone and posting it on social media or group chats.</p><p>📱 <em>Example: “She cheated on her test. I saw it.” (Even if it’s false.)</em></p></li><li><strong>Sharing Private Info Without Permission</strong><p>Posting someone’s personal story, embarrassing photo, or screenshot of a conversation.</p><p>📱 <em>Example: Posting someone’s photo crying in school or in uniform with a joke caption.</em></p></li><li><strong>Fake Profiles or Impersonation</strong><p>Creating a fake account and pretending to be someone else to ruin their reputation.</p><p>📱 <em>Example: Making a fake TikTok account of your classmate to post bad videos.</em></p></li><li><strong>Excluding or Isolating Someone Online</strong><p>Not inviting someone to a group or intentionally leaving them out.</p><p>📱 <em>Example: “Don’t add her, she’s annoying. Let’s keep her out.”</em></p></li><li><strong>Online Threats or Harassment</strong><p>Saying things that make a person feel afraid or unsafe.</p><p>📱 <em>Example: “Watch out after class. I’ll get you.”</em></p></li></ol>
        <hr className="content-divider" />
        <h5>⚠️ Real-Life Impact of Cyberbullying</h5>
        <p>Cyberbullying is not just about hurting feelings — it can seriously affect:</p>
        <ul><li>Mental health (anxiety, depression, sadness)</li><li>School performance (losing focus, skipping classes)</li><li>Friendships and self-esteem</li><li>In severe cases, it can lead to self-harm or worse</li></ul>
        <p>👉 That’s why the law protects every student. It’s not just about punishing bullies. It’s about making sure everyone feels safe, supported, and respected.</p>
        <hr className="content-divider" />
        <h5>🛡️ What the Law Requires Schools to Do</h5>
        <p>Every school in the Philippines is required to:</p>
        <ol><li><strong>Create Clear Anti-Bullying Policies</strong><p>Schools must have written rules to prevent, identify, and stop bullying, including cyberbullying.</p></li><li><strong>Set Up a Reporting System</strong><p>There should be an easy and safe way for students to report bullying without fear of being judged.</p></li><li><strong>Educate Everyone</strong><p>Students, teachers, and even parents must be taught what bullying looks like and how to stop it.</p></li><li><strong>Protect the Victim</strong><p>Schools must make sure victims feel safe and supported — emotionally and physically.</p></li><li><strong>Discipline the Offender</strong><p>Students who bully others, especially online, will face consequences like suspension, counseling, or other interventions.</p></li></ol>
        <hr className="content-divider" />
        <h5>👦 What Can You Do as a Student?</h5>
        <ol><li><strong>Be Responsible.</strong><p>Think before you post. Words and images can hurt deeply.</p></li><li><strong>Be Kind Online.</strong><p>Spread positivity instead of hate. Uplift, don’t tear down.</p></li><li><strong>Don’t Be a Bystander.</strong><p>If you see bullying, speak up. Tell a teacher, parent, or adult.</p></li><li><strong>Report It.</strong><p>Use school reporting channels. Gather proof (screenshots) but don’t share the harmful content.</p></li><li><strong>Support Your Classmates.</strong><p>Sometimes, a kind message or smile can mean a lot.</p></li></ol>
        <hr className="content-divider" />
        <h5>🧭 Final Message</h5>
        <p>Cyberbullying is serious. It is real. And it is against the law.</p>
        <p>Thanks to RA 10627 Section 2-D, students have the right to learn and grow in a safe, supportive environment — including online spaces.</p>
        <p>You have the power to create a better digital world.</p>
        <p>Use your devices to connect, learn, inspire, and make a difference — not to hurt or destroy.</p>

        <h4 style={{marginTop: '3rem', paddingTop: '2rem', borderTop: '1px solid #444'}}>Republic Act No. 10173 — Data Privacy Act of 2012</h4>
        <h5>🔍 Focus: Chapter VIII – Section 26: Accessing Personal Information and Unauthorized Disclosure</h5>
        <hr className="content-divider" />
        <h5>🧾 What is the Data Privacy Act?</h5>
        <p>The Data Privacy Act of 2012 is a Philippine law that protects everyone’s personal information — anything that can be used to identify or trace someone’s identity.</p>
        <p>This law ensures that:</p>
        <ul><li>Our private data is kept safe (name, birthday, school ID, photos, passwords, etc.)</li><li>No one can access, use, or share it without our knowledge and consent</li><li>We have a right to control what happens to our personal data online or offline</li></ul>
        <hr className="content-divider" />
        <h5>💡 What is Personal Information?</h5>
        <p>Personal information is any data that can identify a person, such as:</p>
        <ul><li>Full name</li><li>Birthdate</li><li>Address</li><li>Contact number</li><li>School ID number</li><li>Profile photos</li><li>Email address</li><li>Health records or family background</li></ul>
        <p>Once this data is collected, it must be protected — especially in schools, websites, apps, and government agencies.</p>
        <hr className="content-divider" />
        <h5>📖 Chapter VIII – Section 26: Accessing Personal Information and Unauthorized Disclosure</h5>
        <p>🔍 <strong>What does this section mean?</strong></p>
        <p>Section 26 makes it illegal for anyone (including students, teachers, or even strangers) to:</p>
        <ul><li>🛑 Access personal information without permission</li><li>🛑 Share that information with others (online or offline)</li><li>🛑 Use someone’s private data for bad intentions or without them knowing</li></ul>
        <p>📌 <strong>In Simple Words:</strong></p>
        <p>If you access someone else’s private data (like passwords, ID photos, messages, or grades) without their permission, or you share it with others without consent, you are violating their privacy — and you can be held legally responsible.</p>
        <hr className="content-divider" />
        <h5>💻 Examples of Violations Under Section 26</h5>
        <p>Here are some real-life examples that apply even to students:</p>
        <ol><li><strong>❌ 1. Logging into someone’s account without permission</strong><p><em>Example: Guessing your classmate’s password to open their email or Facebook</em></p></li><li><strong>❌ 2. Sharing someone’s private messages or screenshots in a group chat</strong><p><em>Even if you think it's funny — it's illegal if done without permission</em></p></li><li><strong>❌ 3. Posting another student’s picture online without their approval</strong><p><em>Especially if it can cause embarrassment, harm, or bullying</em></p></li><li><strong>❌ 4. Hacking into the school system to access classmates' grades</strong><p><em>Even "just for fun" — this is a criminal offense</em></p></li><li><strong>❌ 5. Sharing private medical or family information of a student online</strong><p><em>This includes health reports, counseling notes, or family problems</em></p></li></ol>
        <hr className="content-divider" />
        <h5>⚖️ What Are the Consequences?</h5>
        <p>Anyone found violating Section 26 can face:</p>
        <ul><li>Fines up to ₱500,000</li><li>Imprisonment of up to 3 years</li><li>Both penalties depending on how serious the violation is</li></ul>
        <p>👉 Even minors or students can face disciplinary action from school — and in extreme cases, criminal charges if proven guilty with malicious intent.</p>
        <hr className="content-divider" />
        <h5>👩‍🏫 Why is This Important for Students?</h5>
        <p>As students growing up in the digital age, you:</p>
        <ul><li>Use tech every day (Facebook, Messenger, online classes, Google Drive)</li><li>Share information online (forms, photos, group chats)</li><li>Are responsible for using technology in a way that’s safe, respectful, and legal</li></ul>
        <p>This law teaches us to:</p>
        <ul><li>✅ Be careful with the information we share</li><li>✅ Respect the privacy of others</li><li>✅ Ask for consent before posting or sharing anything</li><li>✅ Think before you click or post</li></ul>
        <hr className="content-divider" />
        <h5>🙋 Let’s Practice Digital Responsibility:</h5>
        <table className="styled-table"><thead><tr><th>✅ DOs</th><th>❌ DON’Ts</th></tr></thead><tbody><tr><td>Log out after using shared computers</td><td>Never open someone else’s account, even as a joke</td></tr><tr><td>Ask permission before sharing photos of others</td><td>Don’t repost or share others’ private data</td></tr><tr><td>Report any hacking, data leaks, or bullying</td><td>Don’t leak classmates’ answers, grades, or pictures</td></tr><tr><td>Educate your friends about online privacy</td><td></td></tr></tbody></table>
        <hr className="content-divider" />
        <h5>🧠 Final Message</h5>
        <p>Republic Act 10173 is not just for adults, companies, or government offices.</p>
        <p>It applies to YOU, your school, your friends, and your online behavior.</p>
        <p>It protects everyone’s right to privacy — and reminds us to act honestly, responsibly, and respectfully in the digital world.</p>
        <p>➡️ Be a Digital Citizen who respects privacy.</p><p>➡️ Think before you click.</p><p>➡️ Protect your data and the data of others.</p>

        <h4 style={{marginTop: '3rem', paddingTop: '2rem', borderTop: '1px solid #444'}}>Republic Act No. 8293 – Intellectual Property Code of the Philippines</h4>
        <h5>📌 Focus: Chapter XVII – Sections 216 & 217 (Covers Copyright Infringement and Penalties)</h5>
        <hr className="content-divider" />
        <h5>🤔 What is Intellectual Property?</h5>
        <p>Intellectual Property (IP) refers to creations of the mind. These can include:</p>
        <ul><li>Books, poems, and stories ✍️</li><li>Music, videos, and movies 🎵🎬</li><li>Paintings and drawings 🎨</li><li>Software and games 💻🎮</li><li>Logos and designs 💡</li></ul>
        <p>The person who creates something original is called the author or creator, and they automatically own the rights to that work. These rights protect their creation from being copied or used without permission.</p>
        <hr className="content-divider" />
        <h5>🎓 Why Is This Important to Students?</h5>
        <p>Imagine if you:</p>
        <ul><li>Composed a song</li><li>Drew a digital artwork</li><li>Wrote a short story for school</li></ul>
        <p>You wouldn't want others to steal, copy, or upload it online without your name, right? That’s why the Intellectual Property Code exists — to protect creators and ensure that respect for original work is part of digital citizenship.</p>
        <hr className="content-divider" />
        <h5>🔍 Section 216 – Infringement of Copyright</h5>
        <p>❗ <strong>What is Copyright Infringement?</strong></p>
        <p>Copyright Infringement means using or copying someone else’s original work without permission — especially if:</p>
        <ul><li>You claim it as your own</li><li>You share it publicly</li><li>You profit from it</li><li>You modify it and still don’t give credit</li></ul>
        <p>⚠️ <strong>Common Student Examples of Infringement:</strong></p>
        <ol><li>Copy-pasting articles from the internet without citing the source</li><li>Downloading and sharing pirated movies or music</li><li>Printing copyrighted photos or artwork for school projects without credit</li><li>Uploading someone else’s video and pretending it’s yours</li><li>Using copyrighted music in a video project and posting it online</li></ol>
        <div className="example-box"><p>🧠 <strong>Summary of Section 216:</strong></p><p>This section says that if you copy, reproduce, distribute, or display someone else’s copyrighted work without permission, it is considered a violation of their intellectual rights — even if you're a student.</p><p>You are NOT allowed to:</p><ul><li>Copy entire works without authorization</li><li>Use a copyrighted song in your own video</li><li>Sell printed or digital copies of someone else’s material</li><li>Remove or change the creator’s name or watermark</li></ul></div>
        <hr className="content-divider" />
        <h5>⚖️ Section 217 – Penalties for Infringement</h5>
        <p>So what happens if someone breaks the copyright law?</p>
        <p>🔒 This section talks about two main types of punishment:</p>
        <ol><li><strong>Fines</strong> – You may have to pay ₱50,000 up to ₱1,500,000 depending on the damage caused</li><li><strong>Imprisonment</strong> – From 1 year up to 9 years depending on the seriousness of the violation</li></ol>
        <p>If the infringement is for commercial gain (like selling pirated DVDs, illegal photocopies of books, or bootleg music), the penalties are much higher.</p>
        <hr className="content-divider" />
        <h5>🧠 Simple Examples to Understand It Better</h5>
        <table className="styled-table"><thead><tr><th>Action</th><th>Legal or Illegal?</th><th>Why?</th></tr></thead><tbody><tr><td>Drawing your own cartoon character</td><td>✅ Legal</td><td>You are the original creator</td></tr><tr><td>Downloading a song and using it in a vlog without permission</td><td>❌ Illegal</td><td>Copyrighted music is protected</td></tr><tr><td>Copying a whole Wikipedia article into your school essay</td><td>❌ Illegal</td><td>No citation = plagiarism</td></tr><tr><td>Making a parody video with a disclaimer and giving credit</td><td>⚠️ Depends</td><td>Some parody is allowed under "fair use", but it’s tricky</td></tr></tbody></table>
        <hr className="content-divider" />
        <h5>✅ How to Be a Responsible Digital Citizen</h5>
        <table className="styled-table"><thead><tr><th>✔ DO:</th><th>❌ DON’T:</th></tr></thead><tbody><tr><td>Create your own original work</td><td>Download or share pirated content</td></tr><tr><td>Give credit to the creators of anything you use</td><td>Copy others’ work and claim it as your own</td></tr><tr><td>Use Creative Commons or public domain materials</td><td>Remove watermarks or signatures from images</td></tr><tr><td>Ask permission when needed</td><td>Use copyrighted music or videos in public projects without permission</td></tr><tr><td>Learn about Fair Use (small portions used for education or review)</td><td></td></tr></tbody></table>
        <hr className="content-divider" />
        <h5>📣 Final Message to Students</h5>
        <p>Respecting intellectual property means valuing the hard work and creativity of others — just like you want others to respect your own work. Whether you’re writing, drawing, filming, or designing something, always:</p>
        <ul><li>🔒 Protect your own creations</li><li>🙌 Give credit where it's due</li><li>🚫 Never steal or copy without permission</li></ul>
        <p>Remember, you are creators too — and the law protects YOU just as much as it protects professionals.</p>
    </div>
  ),
  4: <></>, // Course 4 content is now handled specially
  5: (
    <div className="course-discussion-content">
      <h3>Software Applications</h3>
      <p>When you use a computer, smartphone, or tablet, you are actually using different types of software to get things done. Without software, these devices would be useless.</p>
      <p>There are two main types of software you need to understand:</p>
      <ol>
          <li>Application Software</li>
          <li>System Software</li>
      </ol>
      <p>Both are important, but they have different jobs.</p>
      <hr className="content-divider" />

      <h4>1. Application Software</h4>
      <h5>What is Application Software?</h5>
      <p>Application software is a program or group of programs designed to help users perform specific tasks on a computer or device.</p>
      <p>Think of application software as tools that you use to do things like:</p>
      <ul>
          <li>Write a report</li>
          <li>Edit a photo</li>
          <li>Watch a video</li>
          <li>Play a game</li>
          <li>Make a slideshow presentation</li>
      </ul>
      <h5>Simple Example:</h5>
      <p>Imagine your computer is like a toolbox.</p>
      <ul>
          <li>The computer itself is the toolbox.</li>
          <li>Application software is the tools inside the toolbox (like scissors, tape, or a ruler) that help you do a certain job.</li>
      </ul>

      <h5>Common Examples of Application Software:</h5>
      <table className="styled-table">
          <caption>Common Application Software</caption>
          <thead><tr><th>Task</th><th>Application Software Example</th></tr></thead>
          <tbody>
              <tr><td>Writing documents</td><td>Microsoft Word, Google Docs</td></tr>
              <tr><td>Making presentations</td><td>Microsoft PowerPoint, Canva</td></tr>
              <tr><td>Editing photos</td><td>Adobe Photoshop, PicsArt</td></tr>
              <tr><td>Browsing the internet</td><td>Google Chrome, Mozilla Firefox</td></tr>
              <tr><td>Playing games</td><td>Minecraft, Mobile Legends</td></tr>
              <tr><td>Watching videos</td><td>VLC Media Player, YouTube app</td></tr>
              <tr><td>Social media interaction</td><td>Facebook App, Instagram</td></tr>
          </tbody>
      </table>

      <h5>Key Characteristics of Application Software:</h5>
      <ul>
          <li>Helps the user perform a specific task.</li>
          <li>Needs system software to run.</li>
          <li>Can be installed or accessed through apps or web browsers.</li>
          <li>Comes in paid, free, or open-source versions.</li>
      </ul>

      <h5>Real-Life Example for Students:</h5>
      <p>If you’re asked to create a project presentation for Science class, you would use Microsoft PowerPoint or Canva. That’s an example of application software because it helps you create slideshows.</p>

      <hr className="content-divider" />

      <h4>2. System Software</h4>
      <h5>What is System Software?</h5>
      <p>System software is a type of software that helps the computer’s hardware and application software work together. It manages the computer's core functions and makes sure everything runs smoothly.</p>
      <p>Think of system software as the "manager" of your computer.</p>
      
      <h5>Simple Example:</h5>
      <p>Imagine a school:</p>
      <ul>
          <li>The principal and staff (System Software) manage the school so that students and teachers (Application Software) can do their activities properly.</li>
          <li>Without the staff, the school would be chaotic.</li>
      </ul>

      <h5>Types of System Software:</h5>
      <table className="styled-table">
          <caption>Types of System Software</caption>
          <thead><tr><th>Type</th><th>Function</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>Operating System (OS)</td><td>Manages hardware and runs applications</td><td>Windows, macOS, Android, iOS</td></tr>
              <tr><td>Utility Software</td><td>Maintains and protects the system</td><td>Antivirus software, Disk Cleanup</td></tr>
              <tr><td>Device Drivers</td><td>Helps hardware devices work properly</td><td>Printer drivers, Sound drivers</td></tr>
              <tr><td>Language Translators</td><td>Converts programming code into machine code</td><td>Compilers, Interpreters</td></tr>
          </tbody>
      </table>

      <h5>Common Examples of Operating Systems:</h5>
      <table className="styled-table">
          <caption>Common Operating Systems</caption>
          <thead><tr><th>Device</th><th>Operating System Example</th></tr></thead>
          <tbody>
              <tr><td>Personal Computers (PC)</td><td>Microsoft Windows, Linux</td></tr>
              <tr><td>Apple Computers</td><td>macOS</td></tr>
              <tr><td>Smartphones</td><td>Android OS, iOS (for iPhones)</td></tr>
              <tr><td>Tablets</td><td>iPadOS, Android OS</td></tr>
          </tbody>
      </table>
      
      <h5>Key Characteristics of System Software:</h5>
      <ul>
          <li>Runs automatically when you turn on the device.</li>
          <li>Manages all hardware components (like CPU, memory, keyboard, mouse).</li>
          <li>Provides a platform where application software can work.</li>
          <li>Works in the background (users don’t directly interact with it as much).</li>
      </ul>
      
      <h5>Real-Life Example for Students:</h5>
      <p>When you turn on your computer, the Operating System (like Windows 10 or macOS) loads up first. This is system software making sure the keyboard, screen, mouse, and applications can work together properly.</p>
      
      <hr className="content-divider" />
      
      <h4>Difference Between Application Software and System Software</h4>
      <table className="styled-table">
          <caption>Application vs. System Software</caption>
          <thead><tr><th>Feature</th><th>Application Software</th><th>System Software</th></tr></thead>
          <tbody>
              <tr><td>Purpose</td><td>Helps the user perform specific tasks</td><td>Manages hardware and system operations</td></tr>
              <tr><td>User Interaction</td><td>Direct interaction (you use it to do work)</td><td>Works mostly in the background</td></tr>
              <tr><td>Examples</td><td>MS Word, Canva, Chrome, Photoshop</td><td>Windows OS, Android OS, Antivirus</td></tr>
              <tr><td>Installation</td><td>Installed by the user as needed</td><td>Pre-installed or required by system</td></tr>
              <tr><td>Dependency</td><td>Needs system software to function</td><td>Does not need application software to function</td></tr>
          </tbody>
      </table>

      <hr className="content-divider" />

      <h4>Analogy: School Example to Remember</h4>
      <table className="styled-table">
          <caption>School Analogy</caption>
          <thead><tr><th>Computer Concept</th><th>Example in a School</th></tr></thead>
          <tbody>
              <tr><td>Computer Hardware</td><td>The school building and facilities</td></tr>
              <tr><td>System Software (OS)</td><td>The principal and administrative staff</td></tr>
              <tr><td>Application Software</td><td>The teachers and students using classrooms</td></tr>
              <tr><td>User (You)</td><td>The person who uses the school</td></tr>
          </tbody>
      </table>

      <hr className="content-divider" />
      
      <h4>Simple Scenario Example for Students:</h4>
      <p>Imagine you're doing a research project for class:</p>
      <ol>
          <li>You open your laptop (Hardware).</li>
          <li>Your computer turns on and loads Windows 11 (System Software - Operating System).</li>
          <li>You open Google Chrome to browse the internet (Application Software - Web Browser).</li>
          <li>You write your findings in Microsoft Word (Application Software - Word Processor).</li>
      </ol>
      <p>None of this would work if the system software (OS) wasn't there to make sure the hardware and applications could communicate with each other.</p>
      
      <hr className="content-divider" />
      
      <h4>Summary (In Simple Words)</h4>
      <ul>
          <li><strong>System Software</strong> is like the brain of the computer — it makes sure all the parts work together properly.</li>
          <li><strong>Application Software</strong> is like the tools you use to do tasks like writing, designing, or browsing the internet.</li>
          <li>Without system software, your computer wouldn’t even start.</li>
          <li>Without application software, you wouldn’t be able to do tasks like typing reports, playing games, or editing photos.</li>
      </ul>
    </div>
  ),
  6: (
    <div className="course-discussion-content">
        <h3>Introduction to Graphic Design Software</h3>
        <p>Graphic design software are applications or programs used to create and manipulate visual content. These tools are essential for professionals in marketing, advertising, web design, and digital arts. For students, learning to use this software develops creativity, communication, and technical skills.</p>
        <p>Whether you're creating a poster for a school event, designing a logo for a project, or editing photos, graphic design software is your digital toolbox.</p>
        <hr className="content-divider" />

        <h4>Two Main Types of Graphics: Raster vs. Vector</h4>
        <p>Understanding the difference between Raster and Vector graphics is fundamental in digital design, as it determines which software you should use for a specific task.</p>

        <table className="styled-table">
            <caption>Raster vs. Vector Graphics</caption>
            <thead>
                <tr>
                    <th>Feature</th>
                    <th>Raster Graphics</th>
                    <th>Vector Graphics</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td><strong>Made of</strong></td>
                    <td>Pixels (tiny squares of color)</td>
                    <td>Mathematical equations (paths, points, curves)</td>
                </tr>
                <tr>
                    <td><strong>Scalability</strong></td>
                    <td>Loses quality when enlarged (becomes pixelated or blurry)</td>
                    <td>Can be scaled to any size without losing quality</td>
                </tr>
                <tr>
                    <td><strong>Best for</strong></td>
                    <td>Detailed images, photos, digital paintings</td>
                    <td>Logos, icons, illustrations, typography</td>
                </tr>
                <tr>
                    <td><strong>Common File Types</strong></td>
                    <td>JPEG, PNG, GIF, BMP</td>
                    <td>SVG, AI, EPS, PDF</td>
                </tr>
                <tr>
                    <td><strong>Example Software</strong></td>
                    <td>Adobe Photoshop, GIMP, Procreate</td>
                    <td>Adobe Illustrator, Inkscape, CorelDRAW</td>
                </tr>
            </tbody>
        </table>
        
        <div className="example-box">
            <strong>Analogy:</strong> Think of a raster image as a mosaic made of tiny tiles. If you zoom in too much, you'll see the individual tiles. A vector image is like a rubber band; you can stretch it to any size, and it will always remain smooth.
        </div>
        <hr className="content-divider" />

        <h4>Popular Graphic Design Software</h4>
        <p>Let's look at some of the most widely used software in the industry and for beginners.</p>

        <h5>1. Adobe Photoshop (Raster)</h5>
        <p>Photoshop is the industry standard for photo editing and raster-based graphics. It's powerful for manipulating photos, creating digital paintings, and designing web graphics like banners and social media posts.</p>
        <ul>
            <li><strong>Key Features:</strong> Layers, selection tools, brushes, filters, adjustment layers, text tools.</li>
            <li><strong>Best For:</strong> Photo retouching, color correction, creating complex digital art with textures and lighting effects.</li>
        </ul>

        <h5>2. Adobe Illustrator (Vector)</h5>
        <p>Illustrator is the leading software for creating vector graphics. Since its creations are infinitely scalable, it's perfect for logos and designs that need to be used in various sizes, from a small business card to a large billboard.</p>
        <ul>
            <li><strong>Key Features:</strong> Pen tool for drawing paths, shape tools, live paint, gradients, typography controls.</li>
            <li><strong>Best For:</strong> Logo design, icons, illustrations, and infographics.</li>
        </ul>

        <h5>3. Canva (Web-Based - Raster & Vector)</h5>
        <p>Canva is a user-friendly, web-based design platform that simplifies the design process. It's great for beginners and non-designers who need to create professional-looking graphics quickly. It uses a combination of raster images and editable vector elements.</p>
        <ul>
            <li><strong>Key Features:</strong> Drag-and-drop interface, thousands of templates, stock photos and elements, collaboration tools.</li>
            <li><strong>Best For:</strong> Social media posts, presentations, posters, invitations, and simple marketing materials.</li>
        </ul>
         <hr className="content-divider" />

        <h4>Essential Tools and Concepts in Graphic Design Software</h4>
        <table className="styled-table">
            <thead><tr><th>Tool/Concept</th><th>Description</th></tr></thead>
            <tbody>
                <tr><td><strong>Layers</strong></td><td>Like transparent sheets stacked on top of each other. They allow you to work on one part of an image without affecting others.</td></tr>
                <tr><td><strong>Selection Tools</strong></td><td>Used to select a specific area of an image to edit, copy, or move. (e.g., Marquee, Lasso, Magic Wand).</td></tr>
                <tr><td><strong>Pen Tool</strong></td><td>Creates precise paths with anchor points and curves, fundamental for creating vector shapes and illustrations.</td></tr>
                <tr><td><strong>Color Modes (RGB vs. CMYK)</strong></td><td><strong>RGB</strong> (Red, Green, Blue) is for digital screens. <strong>CMYK</strong> (Cyan, Magenta, Yellow, Black) is for print materials.</td></tr>
                <tr><td><strong>Typography</strong></td><td>The art of arranging text to make it legible, readable, and appealing. Involves choosing fonts, font sizes, spacing, and alignment.</td></tr>
                <tr><td><strong>Alignment & Distribution</strong></td><td>Tools that help you arrange objects neatly on your canvas, ensuring a clean and organized layout.</td></tr>
            </tbody>
        </table>

        <hr className="content-divider" />
        <h4>📘 Summary</h4>
        <p>Graphic design software is a powerful gateway to creativity and professional communication. By understanding the difference between raster and vector graphics, you can choose the right tool for your project—whether it's editing a photo in Photoshop, designing a scalable logo in Illustrator, or creating a quick social media post in Canva. Mastering these tools not only enhances your projects but also builds valuable skills for a wide range of future careers.</p>
    </div>
  ),
  7: (
    <div className="course-discussion-content">
      <h3>Introduction to Video Editing</h3>
      <p>Video editing is the process of cutting, arranging, and enhancing video clips to create a final video that tells a story, explains information, or entertains viewers.</p>
      <p>Imagine you filmed several short videos for a school project presentation. Before showing them to your class, you need to:</p>
      <ul>
          <li>Remove unnecessary parts</li>
          <li>Add titles or text</li>
          <li>Put background music</li>
          <li>Arrange the clips in order</li>
      </ul>
      <p>That’s called video editing.</p>
      
      <hr className="content-divider" />
      
      <h4>Why is Video Editing Important?</h4>
      <ul>
          <li>It improves the quality and flow of a video.</li>
          <li>It helps deliver a clear and creative message.</li>
          <li>It makes raw video clips look professional and entertaining.</li>
          <li>It adds effects, transitions, and sounds to keep viewers interested.</li>
      </ul>
      
      <hr className="content-divider" />

      <h4>Fundamentals of Video Editing</h4>
      <table className="styled-table">
          <caption>Key Video Editing Concepts</caption>
          <thead><tr><th>Fundamental Concept</th><th>Description</th></tr></thead>
          <tbody>
              <tr><td>Cutting and Trimming</td><td>Removing unwanted parts of a video clip.</td></tr>
              <tr><td>Sequencing/Arranging</td><td>Placing video clips in the right order to tell a story.</td></tr>
              <tr><td>Transitions</td><td>Adding visual effects to smoothly move from one clip to another.</td></tr>
              <tr><td>Titles and Text</td><td>Adding words on screen (like video titles, subtitles, labels).</td></tr>
              <tr><td>Audio Editing</td><td>Adding background music, voice-overs, or sound effects.</td></tr>
              <tr><td>Visual Effects (VFX)</td><td>Special effects like slow-motion, filters, or color adjustments.</td></tr>
              <tr><td>Exporting</td><td>Saving the final edited video into a file format that can be played or uploaded.</td></tr>
          </tbody>
      </table>

      <hr className="content-divider" />
      
      <h4>Basic Terms in Video Editing</h4>
      <table className="styled-table">
          <caption>Common Video Editing Terms</caption>
          <thead><tr><th>Term</th><th>Definition</th></tr></thead>
          <tbody>
              <tr><td>Clip</td><td>A short piece of video footage.</td></tr>
              <tr><td>Timeline</td><td>The area in video editing software where you arrange and edit clips.</td></tr>
              <tr><td>Cut</td><td>Splitting a clip into smaller parts.</td></tr>
              <tr><td>Trim</td><td>Shortening a clip by cutting parts from the start or end.</td></tr>
              <tr><td>Transition</td><td>Animation or effect between two clips (like fade in/out).</td></tr>
              <tr><td>Overlay</td><td>Adding text, images, or videos on top of existing clips.</td></tr>
              <tr><td>Voice-Over</td><td>Recording and adding narration to a video.</td></tr>
              <tr><td>Audio Track</td><td>The layer where background music or sound effects are placed.</td></tr>
              <tr><td>Rendering/Exporting</td><td>The process of creating the final video file after editing.</td></tr>
              <tr><td>Aspect Ratio</td><td>The width-to-height proportion of the video (like 16:9 for widescreen).</td></tr>
          </tbody>
      </table>

      <hr className="content-divider" />
      
      <h4>Basic Video Editing Process (Step-by-Step)</h4>
      <ol>
          <li>
              <strong>Step 1: Importing Media Files</strong>
              <ul>
                  <li>Import video clips, images, and audio into your video editing software.</li>
                  <li>Example software: CapCut (mobile), Adobe Premiere Pro, Canva Video Editor, Filmora, iMovie.</li>
              </ul>
          </li>
          <li>
              <strong>Step 2: Arranging Clips on the Timeline</strong>
              <ul>
                  <li>Drag and drop video clips onto the timeline.</li>
                  <li>Arrange them in the correct sequence to tell your story.</li>
                  <li>Trim or cut out unnecessary parts to keep only the important scenes.</li>
              </ul>
          </li>
          <li>
              <strong>Step 3: Adding Transitions</strong>
              <ul>
                  <li>Add transitions between clips to make the video flow smoothly.</li>
                  <li>Common transitions: Fade In, Fade Out, Slide, Dissolve.</li>
              </ul>
          </li>
          <li>
              <strong>Step 4: Adding Titles and Text</strong>
              <ul>
                  <li>Insert text overlays like:
                      <ul style={{paddingLeft: '1.5rem', marginTop: '0.5rem'}}>
                          <li>Video Title</li>
                          <li>Captions or subtitles</li>
                          <li>Labels for objects or people in the video</li>
                      </ul>
                  </li>
                  <li>Choose readable fonts and place them at the right spots.</li>
              </ul>
          </li>
          <li>
              <strong>Step 5: Editing Audio</strong>
              <ul>
                  <li>Add background music that matches the mood of your video.</li>
                  <li>Adjust volume levels so that the music doesn't overpower the dialogue.</li>
                  <li>Add voice-over narration if needed.</li>
                  <li>Synchronize sound effects with actions in the video.</li>
              </ul>
          </li>
          <li>
              <strong>Step 6: Applying Effects and Adjustments</strong>
              <ul>
                  <li>Apply filters or color corrections to improve video appearance.</li>
                  <li>Add slow-motion or speed-up effects for dramatic impact.</li>
                  <li>Use zoom-in or pan effects to focus on certain parts of the video.</li>
              </ul>
          </li>
          <li>
              <strong>Step 7: Previewing the Video</strong>
              <ul>
                  <li>Watch the edited video from start to finish.</li>
                  <li>Check for mistakes, wrong cuts, or missing elements.</li>
                  <li>Adjust timing if scenes are too long or too short.</li>
              </ul>
          </li>
          <li>
              <strong>Step 8: Exporting the Final Video</strong>
              <ul>
                  <li>Once satisfied, export or render the video into a file format.</li>
                  <li>Common formats: MP4, MOV, AVI.</li>
                  <li>Choose the right resolution (e.g., 720p, 1080p HD) depending on where you’ll show it.</li>
              </ul>
          </li>
      </ol>

      <hr className="content-divider" />

      <h4>Example Scenario: Editing a Class Project Video</h4>
      <p>You were tasked to create a 3-minute video about your school’s environmental program.</p>
      <p>Here's what you’ll do:</p>
      <ol>
          <li><strong>Import Clips:</strong> Upload all video clips of students planting trees and cleaning surroundings.</li>
          <li><strong>Sequence:</strong> Arrange the clips from the start of the event to the end.</li>
          <li><strong>Trim:</strong> Remove unnecessary shots, like shaky or blurry footage.</li>
          <li><strong>Add Text:</strong> Insert a title screen “Environmental Awareness Program 2025”.</li>
          <li><strong>Insert Transitions:</strong> Add a fade-in transition at the beginning and smooth transitions between clips.</li>
          <li><strong>Audio:</strong> Add light background music and record a voice-over explaining the project.</li>
          <li><strong>Effects:</strong> Apply a bright filter to improve video color.</li>
          <li><strong>Export:</strong> Save as an MP4 file in 1080p resolution to present in class.</li>
      </ol>

      <hr className="content-divider" />
      
      <h4>Common Video Editing Software for Beginners:</h4>
      <table className="styled-table">
          <caption>Beginner Video Editing Software</caption>
          <thead><tr><th>Software Name</th><th>Platform</th><th>Features</th></tr></thead>
          <tbody>
              <tr><td>CapCut</td><td>Mobile (Android/iOS)</td><td>Easy drag-and-drop, filters, text animations</td></tr>
              <tr><td>Canva Video Editor</td><td>Web-based</td><td>Simple video templates, text, and transitions</td></tr>
              <tr><td>iMovie</td><td>macOS/iOS</td><td>Beginner-friendly video editing on Apple</td></tr>
              <tr><td>Filmora</td><td>Windows/Mac</td><td>User-friendly interface, effects, transitions</td></tr>
              <tr><td>Adobe Premiere Rush</td><td>Windows/Mac/Mobile</td><td>Simplified version of Premiere Pro</td></tr>
          </tbody>
      </table>

      <hr className="content-divider" />
      
      <h4>Summary (Simple Version)</h4>
      <ul>
          <li>Video Editing is the process of arranging and improving video clips to create a finished video.</li>
          <li>You will learn to cut clips, add music, insert text, and apply transitions and effects.</li>
          <li>Basic steps include: Importing, Arranging, Trimming, Adding Text and Effects, Audio Editing, and Exporting.</li>
          <li>Common tools are CapCut, Canva Video Editor, iMovie, and Filmora.</li>
          <li>Video editing helps you create creative and professional-looking videos for school projects, social media, or personal use.</li>
      </ul>
    </div>
  )
};

const course4TopicContent = (VideoLink: React.ComponentType<{href: string, children: React.ReactNode}>) => ({
  programming: (
    <div className="course-discussion-content">
      <h4>Tools in Computer Programming</h4>
      <p>Computer Programming Tools are software and platforms that help programmers write, test, debug, and manage code. These tools make it easier to create computer programs, apps, games, websites, and more.</p>
      <p>Just like a carpenter uses a hammer and nails, programmers use digital tools to build software.</p>
      <p>Watch this video: <VideoLink href="https://www.youtube.com/watch?v=us74ML0Y3nY">https://www.youtube.com/watch?v=us74ML0Y3nY</VideoLink></p>
      <hr className="content-divider" />

      <h5>I. Basic Tools Used in Computer Programming</h5>
      <table className="styled-table">
          <thead><tr><th>Tool Type</th><th>Description</th><th>Examples</th></tr></thead>
          <tbody>
              <tr><td>Text Editor</td><td>A simple program where you can write and edit code.</td><td>Notepad (Windows), TextEdit (Mac), Notepad++</td></tr>
              <tr><td>Code Editor</td><td>An advanced text editor designed specifically for coding. It highlights code syntax and helps you write clean code.</td><td>Visual Studio Code (VS Code), Sublime Text, Atom</td></tr>
              <tr><td>Integrated Development Environment (IDE)</td><td>A complete set of tools for writing, testing, and debugging code all in one place. IDEs help manage large projects.</td><td>IDLE (Python’s IDE), Thonny, PyCharm, Eclipse</td></tr>
              <tr><td>Compiler</td><td>Converts source code into a format the computer understands (machine code).</td><td>GCC (for C/C++), Java Compiler</td></tr>
              <tr><td>Interpreter</td><td>Reads and executes code line by line, often used in scripting languages.</td><td>Python Interpreter, JavaScript Engine</td></tr>
              <tr><td>Debugger</td><td>Helps find and fix errors (bugs) in programs by allowing you to examine what’s going wrong step-by-step.</td><td>Built-in Debuggers in IDEs like VS Code, PyCharm</td></tr>
              <tr><td>Version Control System (VCS)</td><td>Tracks changes in code and allows collaboration among programmers.</td><td>Git, GitHub (online platform for sharing code)</td></tr>
              <tr><td>Terminal/Command Line Interface (CLI)</td><td>A text-based tool to run commands, compile programs, and navigate files.</td><td>Command Prompt (Windows), Terminal (Mac/Linux)</td></tr>
          </tbody>
      </table>

      <h5>II. Online Programming Tools & Platforms (For Beginners)</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Description</th><th>Example Use</th></tr></thead>
          <tbody>
              <tr><td>Scratch</td><td>A block-based visual programming language for beginners.</td><td>Making animations and games by dragging code blocks.</td></tr>
              <tr><td>Repl.it (Replit)</td><td>An online code editor and compiler supporting multiple languages.</td><td>Coding directly in a web browser, no installation needed.</td></tr>
              <tr><td>Code.org</td><td>Educational platform with coding tutorials and projects.</td><td>Fun beginner coding activities (Hour of Code).</td></tr>
              <tr><td>Blockly</td><td>Google’s visual programming editor for learning logic.</td><td>Creating simple programs using drag-and-drop blocks.</td></tr>
          </tbody>
      </table>

      <h5>III. Essential Features in Programming Tools</h5>
      <table className="styled-table">
          <thead><tr><th>Feature</th><th>Purpose</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>Syntax Highlighting</td><td>Colors and formats code to make it easier to read.</td><td>Highlights keywords like if, else, while.</td></tr>
              <tr><td>Auto-Completion</td><td>Suggests code while you type to speed up coding.</td><td>Suggests function names and variables.</td></tr>
              <tr><td>Error Highlighting</td><td>Underlines or marks incorrect code.</td><td>Marks missing semicolons or wrong indentations.</td></tr>
              <tr><td>Integrated Debugger</td><td>Lets you test and fix your code step-by-step.</td><td>See what happens in each line of code during runtime.</td></tr>
              <tr><td>Terminal Access</td><td>Run your code or commands directly from the editor.</td><td>Compile a C program from within the IDE.</td></tr>
              <tr><td>Extensions/Plugins</td><td>Add extra features to your code editor.</td><td>Python Linter, HTML Beautifier for VS Code.</td></tr>
          </tbody>
      </table>

      <h5>IV. Common Programming Languages & Their Tools</h5>
      <table className="styled-table">
          <thead><tr><th>Language</th><th>Tool/IDE</th><th>Usage</th></tr></thead>
          <tbody>
              <tr><td>Python</td><td>IDLE, Thonny, PyCharm</td><td>For beginners; used in automation, web apps.</td></tr>
              <tr><td>JavaScript</td><td>VS Code, CodePen (online)</td><td>For web development and interactive websites.</td></tr>
              <tr><td>C/C++</td><td>Dev C++, Code::Blocks</td><td>Systems programming, game development.</td></tr>
              <tr><td>Java</td><td>NetBeans, Eclipse</td><td>Android apps, enterprise applications.</td></tr>
              <tr><td>Scratch</td><td>Scratch Online Editor</td><td>Visual block-based-coding for animations and games.</td></tr>
          </tbody>
      </table>

      <h5>V. Tools for Testing & Debugging Programs</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Purpose</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>Debugger</td><td>Finds logical and runtime errors.</td><td>Breakpoints in VS Code</td></tr>
              <tr><td>Linter</td><td>Checks code for style and syntax errors.</td><td>ESLint for JavaScript</td></tr>
              <tr><td>Unit Testing Tools</td><td>Tests small parts (units) of code automatically.</td><td>PyTest (Python), JUnit (Java)</td></tr>
          </tbody>
      </table>

      <h5>VI. Collaboration & Code Sharing Tools</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Purpose</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>Git</td><td>Tracks changes in your code.</td><td>Saves versions of your project.</td></tr>
              <tr><td>GitHub</td><td>Online platform to share code and collaborate with others.</td><td>Hosting projects, team coding.</td></tr>
              <tr><td>Google Colab</td><td>A collaborative platform for Python coding online.</td><td>Working on machine learning projects or Python tutorials.</td></tr>
          </tbody>
      </table>

      <h5>VII. Importance of Programming Tools</h5>
      <ul>
          <li>Helps beginners write and understand code easily.</li>
          <li>Debugs and fixes errors faster.</li>
          <li>Allows collaboration with classmates or team members.</li>
          <li>Organizes large projects efficiently.</li>
          <li>Enhances productivity through smart features like auto-complete and error highlighting.</li>
      </ul>
      
      <hr className="content-divider" />
      <h4>Summary</h4>
      <ul>
          <li>Programming tools include editors, IDEs, compilers, interpreters, and debuggers.</li>
          <li>Beginners can start with simple tools like Scratch or Replit before moving to advanced IDEs like VS Code or PyCharm.</li>
          <li>Tools like GitHub allow programmers to collaborate and manage projects.</li>
          <li>Learning to use the right tools makes programming easier, faster, and more fun.</li>
      </ul>
    </div>
  ),
  visual_arts: (
    <div className="course-discussion-content">
      <h4>Tools in Computer Visual Arts</h4>
      <p>Computer Visual Arts (also known as Digital Arts) involve creating artworks using digital devices and software. Unlike traditional art tools like brushes and canvases, computer visual arts use digital tools to design, edit, and present creative works.</p>
      <p>These tools are essential for graphic design, digital painting, photo editing, animation, and multimedia arts.</p>
      <hr className="content-divider" />
      
      <h5>I. Hardware Tools (Physical Equipment)</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Description</th><th>Example Brands/Models</th></tr></thead>
          <tbody>
              <tr><td>Computer / Laptop</td><td>The main device where digital art is created and stored.</td><td>Desktop PCs, Macbooks, Laptops</td></tr>
              <tr><td>Graphics Tablet (Drawing Tablet)</td><td>A flat device that allows artists to draw naturally with a stylus pen directly into the computer.</td><td>Wacom, Huion, XP-Pen</td></tr>
              <tr><td>Stylus Pen</td><td>A pen-like tool used with a graphics tablet to draw precisely.</td><td>Wacom Pen, Apple Pencil</td></tr>
              <tr><td>Touchscreen Devices</td><td>Tablets and smartphones with stylus support for digital art.</td><td>iPad with Procreate, Samsung Galaxy Tab</td></tr>
              <tr><td>Mouse</td><td>A basic input device, used for design and navigation.</td><td>Optical mouse for basic graphic editing</td></tr>
              <tr><td>Scanner</td><td>Converts physical artworks or sketches into digital format.</td><td>Flatbed Scanners</td></tr>
              <tr><td>Printer</td><td>Prints digital artworks on paper, canvas, or other materials.</td><td>Inkjet, Laser Printers</td></tr>
              <tr><td>Digital Camera</td><td>Captures high-quality images to be edited or included in artworks.</td><td>DSLR Cameras, Smartphone Cameras</td></tr>
          </tbody>
      </table>

      <h5>II. Software Tools (Programs & Applications)</h5>
      <table className="styled-table">
          <thead><tr><th>Software Type</th><th>Description</th><th>Example Programs</th></tr></thead>
          <tbody>
              <tr><td>Graphics Editing Software</td><td>Used for editing images and designing graphics.</td><td>Adobe Photoshop, Canva, GIMP</td></tr>
              <tr><td>Vector Graphics Software</td><td>For creating logos, icons, and scalable artworks.</td><td>Adobe Illustrator, CorelDRAW, Inkscape</td></tr>
              <tr><td>Digital Painting Software</td><td>Simulates traditional painting tools like brushes and pencils.</td><td>Procreate, Krita, Clip Studio Paint</td></tr>
              <tr><td>3D Modeling Software</td><td>Creates three-dimensional digital sculptures or models.</td><td>Blender, Autodesk Maya, Tinkercad</td></tr>
              <tr><td>Animation Software</td><td>For creating moving illustrations, GIFs, or cartoons.</td><td>Adobe Animate, Synfig Studio, Pencil2D</td></tr>
              <tr><td>Photo Editing Software</td><td>Enhances and corrects photos by adjusting colors, lighting, etc.</td><td>Adobe Lightroom, Snapseed</td></tr>
              <tr><td>Video Editing Software</td><td>Combines visuals, sounds, and effects to create videos.</td><td>Adobe Premiere Pro, CapCut, DaVinci Resolve</td></tr>
              <tr><td>Presentation Software</td><td>Used to create visually engaging reports or slideshows.</td><td>Microsoft PowerPoint, Google Slides</td></tr>
          </tbody>
      </table>

      <h5>III. Basic Digital Art Tools (Software Features)</h5>
      <table className="styled-table">
          <thead><tr><th>Tool / Feature</th><th>Purpose</th><th>Example Usage</th></tr></thead>
          <tbody>
              <tr><td>Brush Tool</td><td>Simulates drawing or painting on a canvas.</td><td>Digital painting, sketching</td></tr>
              <tr><td>Eraser Tool</td><td>Removes parts of the artwork.</td><td>Cleaning edges, correcting mistakes</td></tr>
              <tr><td>Layers Panel</td><td>Separates parts of an artwork for easier editing.</td><td>Background layer, character layer</td></tr>
              <tr><td>Color Picker / Eyedropper Tool</td><td>Selects colors from the artwork.</td><td>Matching exact colors</td></tr>
              <tr><td>Text Tool</td><td>Adds text to an artwork.</td><td>Adding labels or titles</td></tr>
              <tr><td>Shape Tools</td><td>Creates geometric shapes.</td><td>Buttons, icons, design elements</td></tr>
              <tr><td>Selection Tools</td><td>Allows parts of the artwork to be selected and edited.</td><td>Moving objects, cutting out images</td></tr>
              <tr><td>Filters and Effects</td><td>Applies special effects to images.</td><td>Blur, shadow, glow, distortion</td></tr>
              <tr><td>Zoom and Pan Tools</td><td>Lets artists focus on details or move around the canvas.</td><td>Detailing facial features</td></tr>
              <tr><td>Export / Save Options</td><td>Converts the finished work into various file formats.</td><td>JPEG, PNG, PDF</td></tr>
          </tbody>
      </table>
      
      <h5>IV. Online Tools & Platforms</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Description</th><th>Usage</th></tr></thead>
          <tbody>
              <tr><td>Canva</td><td>Web-based design platform with templates.</td><td>Posters, infographics, social media posts</td></tr>
              <tr><td>Pixlr</td><td>Online photo editing software.</td><td>Basic image editing, retouching</td></tr>
              <tr><td>Figma</td><td>Online interface and graphic design tool.</td><td>UI/UX design, collaboration projects</td></tr>
              <tr><td>Google Drawings</td><td>Simple online drawing and diagramming tool.</td><td>School projects, flowcharts</td></tr>
              <tr><td>Medibang Paint</td><td>Cloud-based digital painting tool.</td><td>Comics and illustrations</td></tr>
          </tbody>
      </table>

      <h5>V. Essential Accessories for Digital Artists</h5>
      <table className="styled-table">
          <thead><tr><th>Accessory</th><th>Purpose</th></tr></thead>
          <tbody>
              <tr><td>Stylus Glove</td><td>Reduces friction on the tablet and prevents accidental touches.</td></tr>
              <tr><td>External Storage (USB, Hard Drives)</td><td>Backs up large design files and projects.</td></tr>
              <tr><td>Monitor Calibration Tool</td><td>Ensures colors appear correctly on screen.</td></tr>
              <tr><td>High-Resolution Monitor</td><td>Displays finer details and accurate colors for professional design.</td></tr>
              <tr><td>Drawing Glove (Two-finger glove)</td><td>Helps glide the hand smoothly across a drawing tablet.</td></tr>
          </tbody>
      </table>

      <h5>VI. Advantages of Using Digital Tools in Visual Arts</h5>
      <ul>
        <li>Unlimited Undo/Redo — Correct mistakes instantly.</li>
        <li>Easier Color Selection & Editing — Access to millions of colors.</li>
        <li>Layers for Organizing Artwork — Work on parts of your design without affecting others.</li>
        <li>Global Sharing — Easily upload artworks to social media and online portfolios.</li>
        <li>Cost-Effective — No need to buy canvases, paints, etc.</li>
        <li>Eco-Friendly — Less paper and material waste.</li>
      </ul>

      <h5>VII. Challenges in Computer Visual Arts</h5>
      <ul>
        <li>Requires Equipment — Computers, tablets, and software can be costly.</li>
        <li>Learning Curve — Some programs are complex and need practice.</li>
        <li>Technical Issues — Power interruptions, software bugs, or hardware malfunctions.</li>
        <li>Screen Time Fatigue — Prolonged exposure to screens can strain the eyes.</li>
      </ul>
      
      <h5>VIII. 21st Century Skills Developed through Computer Visual Arts</h5>
      <ul>
        <li>Digital Literacy</li>
        <li>Creativity & Innovation</li>
        <li>Visual Communication</li>
        <li>Critical Thinking & Problem Solving</li>
        <li>Collaboration (Online design projects)</li>
      </ul>

      <hr className="content-divider" />
      <h4>Summary</h4>
      <ul>
        <li>Computer Visual Arts involves using hardware (devices) and software (programs) to create artworks.</li>
        <li>Tools include computers, tablets, stylus pens, graphics software, and online platforms.</li>
        <li>Basic tools like brushes, layers, and effects in software help in creating and editing digital art.</li>
        <li>These tools open doors to careers in graphic design, animation, multimedia arts, web design, and more.</li>
      </ul>
    </div>
  ),
  servicing: (
    <div className="course-discussion-content">
      <h4>Introduction to Computer System Servicing (CSS)</h4>
      <p>Computer System Servicing (CSS) refers to the installation, maintenance, repair, and troubleshooting of computer hardware and software systems. It involves ensuring that computers and peripheral devices (like printers, keyboards, and monitors) are functioning properly.</p>
      <p>CSS is a hands-on technical skill that is very important in today’s digital world where computers are used in homes, schools, offices, and industries.</p>
      <hr className="content-divider" />

      <h5>Importance of Computer System Servicing</h5>
      <ul>
          <li>Ensures that computers work efficiently and last longer.</li>
          <li>Helps in preventing computer failures and data loss.</li>
          <li>Essential for offices, schools, businesses, and even at home.</li>
          <li>Provides a foundation for careers in IT, electronics, and tech support.</li>
          <li>Develops problem-solving, technical, and analytical skills.</li>
      </ul>

      <h5>Basic Components of a Computer System</h5>
      <table className="styled-table">
          <thead><tr><th>Component</th><th>Description</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>System Unit (CPU)</td><td>The main part of a computer containing essential components.</td><td>Motherboard, Processor</td></tr>
              <tr><td>Input Devices</td><td>Devices used to enter data into the computer.</td><td>Keyboard, Mouse</td></tr>
              <tr><td>Output Devices</td><td>Devices that display or produce the result of computer processes.</td><td>Monitor, Printer</td></tr>
              <tr><td>Storage Devices</td><td>Where data is stored.</td><td>Hard Disk Drive (HDD), Solid State Drive (SSD), USB Flash Drive</td></tr>
              <tr><td>Peripheral Devices</td><td>External devices connected to the computer.</td><td>Scanner, Speakers</td></tr>
          </tbody>
      </table>

      <h5>Basic Tools in Computer System Servicing</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Description</th><th>Use</th></tr></thead>
          <tbody>
              <tr><td>Screwdrivers (Phillips, Flathead)</td><td>Used for opening and assembling computer parts.</td><td>Removing CPU covers, securing components</td></tr>
              <tr><td>Anti-Static Wrist Strap</td><td>Prevents static electricity from damaging components.</td><td>Worn during repairs</td></tr>
              <tr><td>Tweezers</td><td>Picks up small screws or components.</td><td>Handling jumpers, small connectors</td></tr>
              <tr><td>Brush (Soft-Bristled)</td><td>Cleans dust and dirt from computer components.</td><td>Cleaning motherboard</td></tr>
              <tr><td>Compressed Air Can</td><td>Blows dust out of hard-to-reach areas.</td><td>CPU fan, power supply unit</td></tr>
              <tr><td>Multimeter</td><td>Measures electrical voltage, current, and resistance.</td><td>Checking power supply</td></tr>
              <tr><td>Cable Ties</td><td>Organizes and secures cables.</td><td>Cable management inside CPU</td></tr>
              <tr><td>Flash Drive (Bootable)</td><td>Used to install operating systems or recovery tools.</td><td>OS installation, troubleshooting</td></tr>
              <tr><td>Software Tools (Utilities)</td><td>Software used for diagnostics, cleaning, or system repairs.</td><td>Disk Cleanup, Antivirus Software</td></tr>
          </tbody>
      </table>

      <h5>Safety Precautions in CSS</h5>
      <ol>
          <li>Always turn off and unplug the computer before servicing.</li>
          <li>Wear an anti-static wrist strap to avoid electrostatic discharge.</li>
          <li>Handle components by the edges, avoid touching circuitry.</li>
          <li>Use tools correctly to avoid damaging parts.</li>
          <li>Keep work area clean and organized.</li>
          <li>Check for power supply safety before plugging in devices.</li>
      </ol>

      <h5>Common Maintenance Tasks</h5>
      <table className="styled-table">
          <thead><tr><th>Task</th><th>Purpose</th></tr></thead>
          <tbody>
              <tr><td>Cleaning Dust</td><td>Prevents overheating and improves airflow.</td></tr>
              <tr><td>Disk Cleanup & Defragmentation</td><td>Improves hard drive performance.</td></tr>
              <tr><td>Virus Scanning</td><td>Protects system from malware and threats.</td></tr>
              <tr><td>Software Updates</td><td>Fixes bugs and improves security.</td></tr>
              <tr><td>Backup Files</td><td>Prevents data loss in case of system failure.</td></tr>
          </tbody>
      </table>

      <h5>Basic Installation Procedures</h5>
      <table className="styled-table">
          <thead><tr><th>Task</th><th>Description</th></tr></thead>
          <tbody>
              <tr><td>Installing Hardware Components</td><td>Adding RAM, Hard Drives, Expansion Cards.</td></tr>
              <tr><td>Connecting Peripheral Devices</td><td>Setting up printers, scanners, webcams.</td></tr>
              <tr><td>Installing Operating Systems (OS)</td><td>Loading Windows, Linux, or other OS into the computer.</td></tr>
              <tr><td>Installing Drivers</td><td>Software that allows the OS to communicate with hardware.</td></tr>
              <tr><td>Installing Utility Software</td><td>Antivirus, Office Applications, Design Software.</td></tr>
          </tbody>
      </table>

      <h5>Troubleshooting Common Computer Problems</h5>
      <table className="styled-table">
          <thead><tr><th>Problem</th><th>Possible Cause</th><th>Solution</th></tr></thead>
          <tbody>
              <tr><td>Computer won’t turn on</td><td>Power cable unplugged, faulty PSU</td><td>Check cables, test PSU</td></tr>
              <tr><td>No display on monitor</td><td>Loose video cable, defective GPU</td><td>Secure connections, replace GPU</td></tr>
              <tr><td>Computer is slow</td><td>Full hard drive, malware infection</td><td>Disk cleanup, virus scan</td></tr>
              <tr><td>No sound</td><td>Muted speakers, driver issues</td><td>Unmute, reinstall drivers</td></tr>
              <tr><td>Overheating</td><td>Dust buildup in fans</td><td>Clean fans and vents</td></tr>
          </tbody>
      </table>

      <h5>CSS Procedures Step-by-Step Example: Installing RAM</h5>
      <ol>
          <li>Turn off the computer and unplug it from the power source.</li>
          <li>Open the case using a screwdriver.</li>
          <li>Locate the RAM slots on the motherboard.</li>
          <li>Align the RAM module’s notch with the slot.</li>
          <li>Press the RAM down until it clicks into place.</li>
          <li>Close the case and plug in the computer.</li>
          <li>Turn on the computer and check if RAM is detected.</li>
      </ol>

      <h5>Careers Related to Computer System Servicing</h5>
      <table className="styled-table">
          <thead><tr><th>Career</th><th>Description</th></tr></thead>
          <tbody>
              <tr><td>Computer Technician</td><td>Repairs and maintains computers and peripherals.</td></tr>
              <tr><td>IT Support Specialist</td><td>Provides technical support in offices, schools, and businesses.</td></tr>
              <tr><td>Network Technician</td><td>Installs and troubleshoots network systems.</td></tr>
              <tr><td>System Administrator</td><td>Manages and configures computer systems and servers.</td></tr>
              <tr><td>Electronics Technician</td><td>Specializes in repairing electronic devices including computers.</td></tr>
          </tbody>
      </table>

      <h5>Essential Skills Developed in CSS</h5>
      <ul>
          <li>Technical Skills — Assembling, disassembling, repairing systems.</li>
          <li>Problem Solving — Diagnosing and fixing hardware/software issues.</li>
          <li>Attention to Detail — Careful handling of delicate components.</li>
          <li>Communication Skills — Explaining technical issues to non-technical users.</li>
          <li>Professionalism & Work Ethics — Following safety and service protocols.</li>
      </ul>

      <hr className="content-divider" />
      <h4>Summary</h4>
      <ul>
          <li>Computer System Servicing involves the installation, maintenance, and troubleshooting of computer systems and peripherals.</li>
          <li>It requires knowledge of hardware components, tools, safety procedures, and problem-solving skills.</li>
          <li>CSS prepares students for technical careers in IT support, computer repair, and system management.</li>
          <li>With computers becoming part of everyday life, CSS skills are highly valuable at home, school, and in professional environments.</li>
      </ul>
    </div>
  ),
  telecom: (
    <div className="course-discussion-content">
      <h4>Tools and Equipment in Telecommunications</h4>
      <p>Telecommunication is the transmission of information over long distances using electronic systems such as phones, internet networks, radios, satellites, and more. It involves both hardware devices and technical tools to send, receive, and manage data.</p>
      <p>Understanding the tools and equipment used in telecommunication is essential for students as it is a fundamental part of modern communication and connectivity.</p>
      <p>Watch this video: <VideoLink href="https://www.youtube.com/watch?v=doom_eEjuiE">https://www.youtube.com/watch?v=doom_eEjuiE</VideoLink></p>
      <hr className="content-divider" />
      
      <h5>I. Telecommunication Devices (Primary Equipment)</h5>
      <table className="styled-table">
          <thead><tr><th>Device</th><th>Description</th><th>Example Use</th></tr></thead>
          <tbody>
              <tr><td>Telephone (Landline)</td><td>A wired device used for voice communication over a network.</td><td>Home or office calls</td></tr>
              <tr><td>Mobile Phone (Cellphone)</td><td>A portable device for wireless communication via cellular networks.</td><td>Calls, SMS, internet access</td></tr>
              <tr><td>Smartphone</td><td>An advanced mobile device that functions like a small computer.</td><td>Voice, video calls, apps, browsing</td></tr>
              <tr><td>Two-Way Radio (Walkie-Talkie)</td><td>A hand-held, portable, short-distance communication device.</td><td>Security communication, events</td></tr>
              <tr><td>Modem (Modulator-Demodulator)</td><td>Converts digital data into signals for transmission over telephone lines or fiber.</td><td>Internet connection</td></tr>
              <tr><td>Router</td><td>Distributes internet connection to multiple devices wirelessly (Wi-Fi).</td><td>Home/office networks</td></tr>
              <tr><td>Switch (Network Switch)</td><td>Connects multiple devices in a wired network to communicate within a LAN.</td><td>Office LAN setup</td></tr>
              <tr><td>Satellite Dish</td><td>Receives and transmits signals to satellites for long-distance communication.</td><td>Satellite TV, remote internet</td></tr>
              <tr><td>Antenna</td><td>A device for sending or receiving radio waves.</td><td>Radio broadcasting, signal boosting</td></tr>
              <tr><td>Smart TV</td><td>A television that can connect to the internet for streaming and apps.</td><td>Watching YouTube, Netflix</td></tr>
          </tbody>
      </table>

      <h5>II. Telecommunication Transmission Media (Cabling and Wireless Medium)</h5>
      <table className="styled-table">
          <thead><tr><th>Medium</th><th>Description</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>Twisted Pair Cable</td><td>Common wired medium made of copper wires twisted together.</td><td>Landline phones, local networks</td></tr>
              <tr><td>Coaxial Cable</td><td>A type of cable used for cable TV and internet connections.</td><td>Cable modems</td></tr>
              <tr><td>Fiber Optic Cable</td><td>Transmits data as light pulses, enabling high-speed internet.</td><td>Fiber-to-home internet</td></tr>
              <tr><td>Microwave Transmission</td><td>Wireless transmission through microwave signals over short distances.</td><td>Telecom towers</td></tr>
              <tr><td>Satellite Transmission</td><td>Uses satellites to transmit signals across long distances.</td><td>International calls, GPS</td></tr>
              <tr><td>Wi-Fi (Wireless Fidelity)</td><td>Wireless technology that connects devices to a local network.</td><td>Home/office internet</td></tr>
              <tr><td>Bluetooth</td><td>Short-range wireless communication between devices.</td><td>Wireless earphones, file sharing</td></tr>
              <tr><td>Infrared (IR)</td><td>Uses infrared light to transmit data over very short distances.</td><td>Remote controls</td></tr>
          </tbody>
      </table>
      
      <h5>III. Tools Used in Telecommunication Servicing & Maintenance</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Description</th><th>Usage</th></tr></thead>
          <tbody>
              <tr><td>Cable Tester</td><td>Tests the integrity and connection quality of cables.</td><td>Checking if LAN cables are working</td></tr>
              <tr><td>Crimping Tool</td><td>Attaches connectors to cables.</td><td>Making network cables (RJ45)</td></tr>
              <tr><td>Punch Down Tool</td><td>Connects wires to a patch panel or keystone jack.</td><td>Network cabling setup</td></tr>
              <tr><td>Wire Stripper</td><td>Removes the insulation from cables.</td><td>Preparing wires for crimping</td></tr>
              <tr><td>Tone Generator & Probe Kit</td><td>Locates and traces cables in walls or bundles.</td><td>Identifying cable ends</td></tr>
              <tr><td>Multimeter</td><td>Measures electrical properties like voltage and resistance.</td><td>Checking power in telecom lines</td></tr>
              <tr><td>Fiber Optic Cleaver</td><td>Precisely cuts fiber optic cables.</td><td>Fiber optic cable splicing</td></tr>
              <tr><td>Optical Power Meter</td><td>Measures signal power in fiber optic lines.</td><td>Fiber network diagnostics</td></tr>
              <tr><td>Screwdrivers (Precision Set)</td><td>Opens telecom devices or panels.</td><td>Installing or repairing equipment</td></tr>
              <tr><td>Labeling Machine</td><td>Creates labels for cables and ports.</td><td>Network organization</td></tr>
          </tbody>
      </table>

      <h5>IV. Support Equipment in Telecommunication Systems</h5>
      <table className="styled-table">
          <thead><tr><th>Equipment</th><th>Function</th></tr></thead>
          <tbody>
              <tr><td>PBX (Private Branch Exchange)</td><td>A private telephone network within an organization.</td></tr>
              <tr><td>Network Rack/Cabinet</td><td>Houses network equipment like routers, switches, and servers.</td></tr>
              <tr><td>UPS (Uninterruptible Power Supply)</td><td>Provides backup power during outages.</td></tr>
              <tr><td>Patch Panel</td><td>Organizes and connects network cables in a central location.</td></tr>
              <tr><td>Signal Booster/Repeater</td><td>Amplifies and extends network signals.</td></tr>
              <tr><td>Modular Crimps and Connectors (RJ45, RJ11)</td><td>Connects cables to devices.</td></tr>
          </tbody>
      </table>

      <h5>V. Modern Telecommunication Tools (Digital Age)</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Description</th><th>Example</th></tr></thead>
          <tbody>
              <tr><td>VoIP Phone (Voice over Internet Protocol)</td><td>Phone that uses internet instead of a traditional telephone lines.</td><td>Skype, Zoom calls</td></tr>
              <tr><td>Video Conferencing Equipment</td><td>Hardware and software used for virtual meetings.</td><td>Webcams, microphones</td></tr>
              <tr><td>Messaging Applications</td><td>Apps used for text, voice, and video communication.</td><td>WhatsApp, Messenger, Viber</td></tr>
              <tr><td>Cloud Storage & Sharing Tools</td><td>Online platforms for storing and sharing files.</td><td>Google Drive, Dropbox</td></tr>
              <tr><td>Unified Communication Systems</td><td>Integrates multiple communication tools (voice, video, messaging) in one platform.</td><td>Microsoft Teams, Slack</td></tr>
          </tbody>
      </table>

      <h5>VI. Safety Tools in Telecommunication Work</h5>
      <table className="styled-table">
          <thead><tr><th>Tool</th><th>Purpose</th></tr></thead>
          <tbody>
              <tr><td>Hard Hat</td><td>Protects the head when working on telecom towers or construction sites.</td></tr>
              <tr><td>Safety Harness & Lanyard</td><td>Prevents falls when climbing poles or towers.</td></tr>
              <tr><td>Safety Glasses</td><td>Protects eyes from dust and debris.</td></tr>
              <tr><td>Gloves (Rubber/Insulated)</td><td>Protects hands while handling cables and equipment.</td></tr>
              <tr><td>High-Visibility Vest</td><td>Ensures visibility in work areas with traffic or machinery.</td></tr>
          </tbody>
      </table>

      <h5>Importance of Telecommunication Tools and Equipment</h5>
      <ul>
          <li>Ensures efficient and reliable communication systems.</li>
          <li>Helps technicians install, maintain, and troubleshoot telecom infrastructure.</li>
          <li>Essential for enabling internet connectivity, mobile services, and digital communication.</li>
          <li>Supports business operations, education, healthcare, and daily activities.</li>
      </ul>

      <hr className="content-divider" />
      <h4>Summary</h4>
      <ul>
          <li>Telecommunication involves a variety of devices (phones, routers, satellites), transmission media (cables, wireless signals), and servicing tools (crimpers, testers).</li>
          <li>Technicians use specialized tools to install, maintain, and troubleshoot networks.</li>
          <li>Telecommunication tools are vital in providing connectivity for homes, schools, businesses, and industries.</li>
          <li>Learning about these tools prepares students for basic ICT infrastructure understanding and potential careers in telecommunication technology.</li>
      </ul>
    </div>
  )
});

const quizzes: { [key: number]: { [key: string]: any[] } } = {
    1: {
        part1: [
            { question: "Why is it important for John’s website to be mobile-friendly in the context of digital marketing success?", options: ["Most customers shop only during work hours", "Mobile-friendly websites are easier to code", "A large portion of users access websites through mobile devices", "Desktop websites load faster than mobile versions"], correctAnswer: "C" },
            { question: "If John notices that his blog posts get traffic but few product purchases, what should he focus on improving based on the video?", options: ["The color scheme of his website", "The shipping speed of his products", "The call-to-action (CTA) and link to his product pages", "The number of social media followers he has"], correctAnswer: "C" },
            { question: "Which of the following best explains why SEO is considered a long-term strategy rather than a quick fix?", options: ["SEO works only when used with paid ads", "It requires constant changes to the website theme", "Search engine rankings take time to build and improve", "It only works if influencers are involved"], correctAnswer: "C" },
            { question: "John is choosing between influencer marketing and content marketing. If he wants quick results and access to a large audience, which is the better option and why?", options: ["Content marketing, because it requires fewer tools", "Influencer marketing, because it offers immediate exposure", "SEO, because it gives organic traffic", "Paid ads, because they are always free to run"], correctAnswer: "B" },
            { question: "Which strategy allows John to market his products through other websites in exchange for a commission, and why might this be effective?", options: ["Email marketing; because it builds long-term relationships", "Paid advertising; because it’s highly controlled", "Affiliate marketing; because it leverages other people’s audiences", "Social media; because it’s visually appealing"], correctAnswer: "C" }
        ],
        part2: [
            { question: "According to the second video, what is a primary use of AI tools like ChatGPT in digital marketing?", options: ["Designing website layouts", "Generating written content like blog posts and emails", "Processing online payments", "Directly managing customer deliveries"], correctAnswer: "B" },
            { question: "The video mentions AI tools for creating visual content. Which tool is specifically named for generating images from text descriptions?", options: ["Canva", "CapCut", "Midjourney", "Adobe Photoshop"], correctAnswer: "C" },
            { question: "What is the benefit of using an AI tool like Synthesia, as shown in the video?", options: ["It automatically optimizes website SEO.", "It creates realistic video presentations with AI avatars, saving filming costs.", "It analyzes competitor ad campaigns.", "It provides a free platform for hosting videos."], correctAnswer: "B" },
            { question: "How do AI tools help marketers become more efficient?", options: ["By replacing the need for a marketing strategy.", "By automating repetitive and time-consuming tasks.", "By offering free advertising credits.", "By guaranteeing viral content every time."], correctAnswer: "B" }
        ],
        final: [
            { question: "What is the primary goal of digital marketing?", options: ["To replace traditional advertising completely", "To use digital channels to promote products or services", "To create viral videos on TikTok", "To sell products only through physical stores"], correctAnswer: "B" },
            { question: "Which of the following is an example of using ICT to 'create content' for digital marketing?", options: ["Receiving a payment via GCash", "Replying to a customer on Facebook Messenger", "Using Canva to design a promotional poster", "Booking a delivery with Lalamove"], correctAnswer: "C" },
            { question: "Why is a mobile-friendly website crucial for digital marketing?", options: ["It's cheaper to host", "It ranks higher on desktop searches by default", "A large number of users browse and shop on their phones", "Mobile sites don't need security"], correctAnswer: "C" },
            { question: "What does SEO stand for and why is it considered a long-term strategy?", options: ["Social Engagement Optimization; it requires daily posting", "Search Engine Optimization; it takes time to build authority and rankings", "Sales Efficiency Organization; it organizes your sales team", "Secure E-commerce Operation; it focuses on payment security"], correctAnswer: "B" },
            { question: "If a business wants immediate exposure to a large, targeted audience, which strategy from the video would be most effective?", options: ["Content Marketing", "Affiliate Marketing", "Email Marketing", "Influencer Marketing"], correctAnswer: "D" },
            { question: "Which platform is primarily used for professional networking and B2B (business-to-business) marketing?", options: ["TikTok", "Instagram", "LinkedIn", "Facebook"], correctAnswer: "C" },
            { question: "An AI tool like Midjourney is used for what purpose in digital marketing?", options: ["Writing blog posts", "Generating unique images from text prompts", "Creating AI video avatars", "Analyzing website traffic"], correctAnswer: "B" },
            { question: "What is affiliate marketing?", options: ["Paying an influencer to post about your product", "Sending promotional emails to a list of subscribers", "Partnering with others to promote your product in exchange for a commission on sales", "Improving your website to rank higher on Google"], correctAnswer: "C" },
            { question: "What does the term 'call-to-action' (CTA) refer to?", options: ["The main headline of an advertisement", "A prompt designed to provoke an immediate response, like 'Shop Now' or 'Learn More'", "A customer service phone number", "The terms and conditions of a sale"], correctAnswer: "B" },
            { question: "How does an AI tool like Synthesia help businesses save costs?", options: ["It provides free advertising on social media", "It creates videos with AI avatars, eliminating the need for actors and film crews", "It automates the delivery process", "It designs logos for free"], correctAnswer: "B" },
            { question: "Why is learning ICT for online marketing considered empowering for students?", options: ["It allows them to hack into school computers", "It equips them with practical entrepreneurial skills using accessible tools", "It guarantees they will become wealthy", "It's the only subject needed to graduate"], correctAnswer: "B" },
            { question: "What does being a responsible 'Digital Citizen' primarily involve?", options: ["Using the internet as much as possible", "Knowing how to get free Wi-Fi", "Navigating the digital world safely, ethically, and respectfully", "Having accounts on all social media platforms"], correctAnswer: "C" },
            { question: "Which of these is an example of poor 'Netiquette' (Digital Etiquette)?", options: ["Respecting others' opinions in a discussion forum", "Citing sources when using information from the web", "TYPING A COMMENT IN ALL CAPS TO SHOW YOU ARE ANGRY", "Sending a formal email to a teacher"], correctAnswer: "C" },
            { question: "According to the course summary, what is a key benefit of digital marketing over traditional marketing?", options: ["It is more expensive but more effective", "It reaches fewer people but they are more likely to buy", "It is only suitable for large corporations", "It allows sellers to reach more people faster and at a lower cost"], correctAnswer: "D" },
            { question: "If Liza, the student selling scrunchies, uses GCash to receive money, which part of the ICT-powered marketing process is this?", options: ["Create content", "Promote products", "Sell and collect payment", "Deliver products"], correctAnswer: "C" },
        ]
    },
    2: {
        final: [
            { question: "Which of the following situations best shows a student using Digital Etiquette?", options: ["Posting memes without checking if they might offend someone", "Ignoring messages from classmates in a group chat", "Saying “thank you” and replying respectfully to online comments", "Typing in ALL CAPS during an online discussion"], correctAnswer: "C" },
            { question: "Why is it important to understand your digital footprint?", options: ["It helps you post more photos online", "It shows how many followers you have", "It affects how others see you and what they know about you", "It lets you delete everything easily"], correctAnswer: "C" },
            { question: "You see a post from a classmate bullying another student. What’s the best action to take as a responsible digital citizen?", options: ["Ignore it", "Join the comments to tease the person too", "Share the post with more friends", "Report it and support the victim"], correctAnswer: "D" },
            { question: "A website asks for your personal information before giving access. What should you do?", options: ["Immediately provide your full name and address", "Exit the site and double-check if it’s safe", "Post your info on social media for easy access", "Trust any site with a lot of images"], correctAnswer: "B" },
            { question: "Which best explains why Digital Literacy is important?", options: ["To follow more celebrities", "To play games more efficiently", "To recognize reliable online information and use technology wisely", "To type faster on your phone"], correctAnswer: "C" },
            { question: "Which of the following is an example of practicing Digital Law?", options: ["Sharing your classmate’s homework online", "Downloading songs from illegal websites", "Citing sources correctly in your online project", "Copying images from Google without permission"], correctAnswer: "C" },
            { question: "What is the biggest risk of oversharing your personal information online?", options: ["You might get more likes", "Your teacher might give you more homework", "You might be targeted by strangers or scammers", "Your post might be boring"], correctAnswer: "C" },
            { question: "How can you show Digital Responsibility in a group project done online?", options: ["Take credit for all the work", "Only chat with your friends and ignore the rest", "Respect deadlines and contribute fairly", "Copy and paste others’ ideas from websites"], correctAnswer: "C" },
            { question: "Which situation best shows awareness of Digital Health and Wellness?", options: ["Using your phone during meals and before sleep", "Taking screen breaks every hour and sitting with good posture", "Playing online games until midnight", "Posting selfies every 5 minutes"], correctAnswer: "B" },
            { question: "What is the most responsible use of Digital Communication?", options: ["Sharing secrets in group chats", "Spamming group chats with memes", "Giving clear, respectful, and honest responses online", "Arguing with classmates in comment sections"], correctAnswer: "C" },
            { question: "How can a student help promote Digital Access at school?", options: ["Making fun of classmates without phones", "Helping others use a shared computer during group work", "Refusing to work with those who don’t know technology", "Keeping the computer all to yourself"], correctAnswer: "B" },
            { question: "Which is the most secure password?", options: ["123456", "iloveyou", "School2025!@", "password"], correctAnswer: "C" },
            { question: "How does your digital identity form over time?", options: ["By how many online games you play", "Through your online actions, posts, comments, and shared content", "Only by your profile picture", "By how long you stay online"], correctAnswer: "B" },
            { question: "A student edits a classmate's photo and posts it as a joke. What rule of digital citizenship did they break?", options: ["Digital Access", "Digital Commerce", "Digital Law and Etiquette", "Digital Literacy"], correctAnswer: "C" },
            { question: "Which of the following shows the best use of Digital Security?", options: ["Using the same password everywhere for easy memory", "Writing your password on your desk", "Sharing passwords with friends for “trust”", "Using two-factor authentication and a strong password"], correctAnswer: "D" },
            { question: "Why is it important to think before posting something online?", options: ["Because your friends might not see it", "So that you don’t run out of storage space", "Because it can affect your digital reputation and stay online forever", "Because posts disappear after 5 minutes"], correctAnswer: "C" },
            { question: "Which example best shows responsible use of Digital Commerce?", options: ["Buying from unknown websites with no reviews", "Sharing your bank info with a friend over chat", "Using a secure site with a lock symbol to purchase a school book", "Entering your credit card on any site that looks colorful"], correctAnswer: "C" },
            { question: "Which of the following best explains how to protect your Digital Identity?", options: ["Use your real birthday as your password", "Keep personal information private and use privacy settings", "Let everyone see your posts to get more likes", "Use your school email for all gaming accounts"], correctAnswer: "B" },
            { question: "If you’re unsure whether an online source is true or fake, what should you do?", options: ["Share it just in case it’s true", "Assume it’s right if it sounds interesting", "Cross-check it with other reliable websites or sources", "Only believe it if it’s on social media"], correctAnswer: "C" },
            { question: "How can you help others become better digital citizens?", options: ["Tell them to spend less time online", "Ask them to ignore rules and have fun", "Teach them about online safety, kindness, and responsibility", "Tell them to post everything they do for attention"], correctAnswer: "C" }
        ]
    },
    3: {
        final: [
            { question: "Why is it important that DICT ensures ICT access in far-flung areas of the country?", options: ["To allow more people to play online games", "To improve digital literacy and equal opportunities for all", "To monitor online behavior of rural citizens", "To make urban centers more advanced"], correctAnswer: "B" },
            { question: "If DICT partners with schools to train teachers in cybersecurity, which of its powers under Section 5 is being applied?", options: ["Composition of the agency", "Authority to plan ICT infrastructure", "Supporting digital education and training", "Regulating media platforms"], correctAnswer: "C" },
            { question: "Why would Section 6 of RA 10844 (about DICT officials) matter to ordinary citizens?", options: ["Because knowing names helps you contact them", "Because leadership structure affects policy decisions and efficiency", "Because it tells you who to blame during issues", "Because you need to memorize all the positions"], correctAnswer: "B" },
            { question: "What higher purpose does RA 10627 serve beyond just punishing bullies?", options: ["It protects the bullies' right to free speech", "It promotes online fun through pranks", "It builds a culture of empathy and safety in learning spaces", "It increases use of social media"], correctAnswer: "C" },
            { question: "Why is cyberbullying more dangerous than traditional bullying?", options: ["It is more fun for others to watch", "It is harder to get caught", "It spreads quickly and happens anytime", "It doesn't hurt as much as face-to-face bullying"], correctAnswer: "C" },
            { question: "If a student sends screenshots of private messages without consent, what two laws might they be violating?", options: ["RA 10627 and RA 8293", "RA 10173 and RA 10627", "RA 10844 and RA 8293", "RA 10173 and RA 10844"], correctAnswer: "B" },
            { question: "Why is RA 10173 especially important in the age of social media?", options: ["Because social media makes everything boring", "Because it makes it easier to copy posts", "Because people can share personal data instantly and unknowingly", "Because fewer people use social media"], correctAnswer: "C" },
            { question: "What is the main idea behind RA 10173 Section 26?", options: ["Encouraging people to create content", "Preventing the unauthorized use and sharing of personal data", "Allowing the government to access your accounts", "Giving schools full control over student data"], correctAnswer: "B" },
            { question: "How does respecting intellectual property make you a good digital citizen?", options: ["You get more followers", "You can copy smarter", "You promote honesty and value creativity", "You avoid having to study"], correctAnswer: "C" },
            { question: "A student edits and shares a classmate’s digital painting as a meme without permission. What law is being violated?", options: ["RA 10844", "RA 8293", "RA 10173", "RA 10627"], correctAnswer: "B" },
            { question: "When DICT trains LGUs and schools on ICT systems, what role is it fulfilling?", options: ["Mandate to punish students", "Authority to own schools", "Function to develop digital literacy and support public services", "Power to manage media companies"], correctAnswer: "C" },
            { question: "What makes fake accounts dangerous in cyberbullying?", options: ["They're used for funny posts", "They hide the bully’s identity and can spread harm widely", "They are good for school projects", "They're easy to delete"], correctAnswer: "B" },
            { question: "Why is posting private health records a serious offense under RA 10173?", options: ["Because it's boring", "Because it's about medical science", "Because it involves sensitive personal data protected by law", "Because teachers will be angry"], correctAnswer: "C" },
            { question: "Which scenario is a clear example of copyright infringement?", options: ["Sharing your own poem online", "Watching a friend’s TikTok", "Downloading and posting a full movie on YouTube", "Singing in karaoke"], correctAnswer: "C" },
            { question: "Why is giving credit to creators essential even in school projects?", options: ["So you get a higher grade", "So you don’t get caught copying", "Because it respects ownership and avoids plagiarism", "Because your teacher said so"], correctAnswer: "C" },
            { question: "A group of students develop a learning app. What legal action protects their creation?", options: ["Submitting it to DICT", "Reporting it to school", "Protecting it under RA 8293", "Sharing it on social media"], correctAnswer: "C" },
            { question: "A student films a classmate crying and posts it without permission. Which two laws may be violated?", options: ["RA 10173 and RA 10627", "RA 10844 and RA 8293", "RA 10627 and RA 8293", "RA 10173 and RA 10844"], correctAnswer: "A" },
            { question: "Which part of the DICT’s mandate helps promote safety from cyberbullying?", options: ["Setting up online payment systems", "Promoting e-governance only", "Supporting cybersecurity education and awareness", "Replacing teachers with robots"], correctAnswer: "C" },
            { question: "If a student sells pirated e-books to classmates, which law applies?", options: ["RA 10844", "RA 10627", "RA 10173", "RA 8293"], correctAnswer: "D" },
            { question: "Why is knowing about ICT-related laws important for students?", options: ["To avoid being scolded", "To succeed in online games", "To be safe, smart, and responsible in the digital world", "To join the DICT"], correctAnswer: "C" }
        ]
    },
    4: {
        programming: [
            { question: "Which of the following best explains why an Integrated Development Environment (IDE) is preferred over a basic text editor when working on a large programming project?", options: ["It has colorful themes that make the code look nice.", "It can compile, debug, and manage projects all in one place.", "It allows you to write longer sentences in your program.", "It saves your program automatically every 10 minutes."], correctAnswer: "B" },
            { question: "You and your classmates are collaborating on a coding project from different locations. Which of the following tools will BEST help you manage code versions and work together?", options: ["Notepad++", "Scratch", "GitHub", "Microsoft PowerPoint"], correctAnswer: "C" },
            { question: "Your classmate is using Notepad to write a Python program but keeps making syntax errors that are hard to find. Which tool would you recommend to help them see these errors as they type?", options: ["Visual Studio Code (VS Code)", "Calculator", "Google Chrome", "Windows Media Player"], correctAnswer: "A" },
            { question: "Which of the following workflows correctly shows the order of using tools when writing, testing, and fixing a simple program?", options: ["Browser → Debugger → Text Editor", "Text Editor → Compiler/Interpreter → Debugger", "Printer → Calculator → Paint", "Text Editor → Linter → Spreadsheet Software"], correctAnswer: "B" },
            { question: "You want to help your classmates transition from Scratch (block-based coding) to text-based coding. Which activity will BEST achieve this goal?", options: ["Ask them to stop using Scratch immediately.", "Let them manually type out the Scratch blocks in Notepad.", "Use a tool like Blockly that shows both blocks and the equivalent text code.", "Skip coding practice and give them a coding quiz instead."], correctAnswer: "C" }
        ],
        visual_arts: [
            { question: "Which of the following BEST explains why using a graphics tablet with a stylus pen is more effective than a mouse when creating detailed digital illustrations?", options: ["A stylus pen has more buttons than a mouse.", "A stylus pen allows for precise hand-drawn input, simulating traditional drawing.", "A mouse moves faster across the screen than a stylus pen.", "A mouse automatically corrects drawing mistakes."], correctAnswer: "B" },
            { question: "You are tasked to create an animated school logo that moves and spins. Which software category should you use to complete this project?", options: ["Photo Editing Software", "Animation Software", "Vector Graphics Software", "Presentation Software"], correctAnswer: "B" },
            { question: "A classmate is designing a poster but struggles with aligning shapes and text perfectly. Which software feature would you recommend they focus on to improve their layout precision?", options: ["Brush Tool", "Filters and Effects", "Layers Panel", "Shape and Selection Tools"], correctAnswer: "D" },
            { question: "You are designing a digital art piece that combines scanned pencil sketches with digital coloring and text. Which combination of hardware and software tools would you most likely use to complete this project?", options: ["Scanner, Digital Camera, Video Editing Software", "Scanner, Graphics Tablet, Graphics Editing Software", "Printer, Monitor Calibration Tool, Presentation Software", "Touchscreen Device, External Storage, Photo Editing Software"], correctAnswer: "B" },
            { question: "Your school is hosting an online art exhibit where students must submit digital artworks. Which of the following sequences of tools and platforms will BEST help you create, edit, and share your work?", options: ["Drawing Tablet → Digital Painting Software → Export as JPEG → Upload to Online Platform", "Mouse → Calculator → Print Artwork → Submit via Email", "Stylus Glove → Printer → Post on Social Media → Edit in Word Processor", "Webcam → Video Editing Software → Save as PDF → Share via Flash Drive"], correctAnswer: "A" }
        ],
        servicing: [
            { question: "A computer is frequently overheating and shutting down. After opening the CPU, you notice dust buildup in the cooling fan and vents. Which tool should you use FIRST to safely clean it?", options: ["Screwdriver", "Tweezers", "Compressed Air Can", "Multimeter"], correctAnswer: "C" },
            { question: "Your school computer lab has computers that are running very slowly. As a CSS technician, which software tool or task will you perform to improve their performance?", options: ["Run Disk Cleanup and Defragmentation", "Use the Brush Tool to clean the motherboard", "Reinstall the monitors and keyboards", "Tighten the screws on the CPU with a screwdriver"], correctAnswer: "A" },
            { question: "You are installing a new printer, but the computer is not recognizing it after connection. Which of the following is the best next step in troubleshooting?", options: ["Replace the printer with a new one immediately", "Install the necessary printer driver software", "Use a multimeter to check the printer's voltage", "Clean the printer with a soft-bristled brush"], correctAnswer: "B" },
            { question: "You are assigned to build a step-by-step troubleshooting guide for computers that \"do not turn on.\" Which of the following sequence of actions is the most logical order?", options: ["Replace the monitor → Check PSU with multimeter → Secure power cables", "Check power cables → Test PSU with multimeter → Inspect motherboard connections", "Run Disk Cleanup → Open CPU case → Clean dust from fans", "Plug in a flash drive → Install utility software → Replace CPU"], correctAnswer: "B" },
            { question: "You are tasked to design a basic maintenance checklist for the school’s computer lab. Which of the following should NOT be included in your weekly maintenance tasks?", options: ["Cleaning dust from CPU fans", "Updating antivirus and scanning for malware", "Installing a new operating system on every computer", "Organizing cables and checking for loose connections"], correctAnswer: "C" }
        ],
        telecom: [
            { question: "A technician is setting up a Local Area Network (LAN) in an office using twisted pair cables. After attaching connectors, they need to ensure the cables are properly transmitting signals. Which tool should they use to verify the cable’s integrity?", options: ["Crimping Tool", "Cable Tester", "Punch Down Tool", "Tone Generator"], correctAnswer: "B" },
            { question: "Your school's internet is shared among multiple computers through a wireless connection. Which telecommunication device distributes this connection to students and teachers?", options: ["Switch", "Modem", "Router", "PBX (Private Branch Exchange)"], correctAnswer: "C" },
            { question: "A team is installing fiber optic cables for a high-speed internet connection. The technician needs to precisely cut the fiber cable for splicing. Which tool is the most appropriate for this task?", options: ["Wire Stripper", "Fiber Optic Cleaver", "Optical Power Meter", "Multimeter"], correctAnswer: "B" },
            { question: "You are to design a safe work plan for technicians who will climb telecom towers for maintenance. Which combination of safety tools must be included to ensure their safety?", options: ["Safety Harness, Hard Hat, Gloves", "Screwdrivers, Cable Tester, Safety Glasses", "High-Visibility Vest, Multimeter, Crimping Tool", "Patch Panel, Signal Booster, Modular Crimps"], correctAnswer: "A" },
            { question: "Your class is tasked to set up a school video conference system for virtual meetings. Which of the following combination of tools and equipment would you recommend?", options: ["VoIP Phone, Patch Panel, Safety Lanyard", "Webcam, Microphone, Video Conferencing Software", "Wire Stripper, PBX, Optical Power Meter", "Two-Way Radio, Crimping Tool, Satellite Dish"], correctAnswer: "B" }
        ]
    },
    5: {
        final: [
            { question: "What is the main function of Application Software?", options: ["To manage computer hardware resources", "To help the user perform specific tasks", "To start up the computer", "To protect the computer from viruses"], correctAnswer: "B" },
            { question: "Which of the following is an example of System Software?", options: ["Microsoft PowerPoint", "Google Chrome", "Windows 11 Operating System", "Adobe Photoshop"], correctAnswer: "C" },
            { question: "A student is writing a school report using Google Docs. Which type of software are they primarily using?", options: ["System Software", "Utility Software", "Application Software", "Device Driver"], correctAnswer: "C" },
            { question: "Which software acts as the 'manager' of the computer, controlling the hardware and providing a platform for other programs?", options: ["Application Software", "Operating System", "Web Browser", "Word Processor"], correctAnswer: "B" },
            { question: "Microsoft Word, Canva, and Minecraft are all examples of...?", options: ["System Software", "Operating Systems", "Application Software", "Utility Software"], correctAnswer: "C" },
            { question: "What is the key relationship between Application Software and System Software?", options: ["System software is installed on top of application software", "They are the same type of software", "Application software needs system software to run", "System software cannot run without application software"], correctAnswer: "C" },
            { question: "Which of the following is NOT an example of an Operating System?", options: ["Android OS", "macOS", "Adobe Photoshop", "Linux"], correctAnswer: "C" },
            { question: "When you turn on your computer, what is the first type of software to load and run?", options: ["Web Browser", "Application Software", "System Software (Operating System)", "Antivirus Program"], correctAnswer: "C" },
            { question: "Antivirus programs and disk cleanup tools are part of a sub-category of system software known as...", options: ["Application Suites", "Device Drivers", "Utility Software", "Compilers"], correctAnswer: "C" },
            { question: "In the 'school' analogy from the lesson, what does the principal and administrative staff represent?", options: ["Application Software", "The User", "System Software", "Computer Hardware"], correctAnswer: "C" }
        ]
    },
    6: {
        final: [
            { question: "What is the primary difference between raster and vector graphics?", options: ["Raster is for print, Vector is for web", "Raster is made of pixels, Vector is made of mathematical paths", "Raster files are smaller than Vector files", "Raster uses CMYK, Vector uses RGB"], correctAnswer: "B" },
            { question: "If you were designing a company logo that needs to be resized for a business card and a large billboard, which type of graphic would be BEST to use?", options: ["Raster, because it handles details well", "Vector, because it can be scaled without losing quality", "Pixelated, because it is modern", "JPEG, because it is a common file type"], correctAnswer: "B" },
            { question: "A student enlarges a photograph for a poster, and it becomes blurry and pixelated. This is a characteristic of what type of graphic?", options: ["Vector", "SVG", "Raster", "AI"], correctAnswer: "C" },
            { question: "Which software is considered the industry standard for editing photos and creating raster-based digital art?", options: ["Adobe Illustrator", "Canva", "Microsoft Word", "Adobe Photoshop"], correctAnswer: "D" },
            { question: "A designer is creating a set of icons for a mobile app. Which software would be most suitable for this task?", options: ["Adobe Photoshop, because icons have lots of colors", "Adobe Illustrator, because icons need to be scalable and clean", "Procreate, because it's good for painting", "GIMP, because it is a free photo editor"], correctAnswer: "B" },
            { question: "What is the main advantage of using a web-based tool like Canva for a beginner?", options: ["It has the most advanced features for professional artists", "It requires a powerful computer to run", "It offers a user-friendly interface with templates for quick designs", "It only creates vector graphics"], correctAnswer: "C" },
            { question: "What is the function of 'Layers' in graphic design software?", options: ["To change the file format of the image", "To stack elements on top of each other and edit them independently", "To automatically correct the colors in a photo", "To add a filter to the entire image"], correctAnswer: "B" },
            { question: "You are designing a poster that will be printed. Which color mode should you ideally use to ensure the colors are accurate on paper?", options: ["RGB (Red, Green, Blue)", "Grayscale", "CMYK (Cyan, Magenta, Yellow, Black)", "HEX"], correctAnswer: "C" },
            { question: "Which tool is essential for creating precise, custom shapes and paths in a vector graphics program like Adobe Illustrator?", options: ["Brush Tool", "Eraser Tool", "Pen Tool", "Magic Wand Tool"], correctAnswer: "C" },
            { question: "Which of the following file types is a common format for a vector graphic?", options: ["JPEG", "PNG", "SVG", "GIF"], correctAnswer: "C" }
        ]
    },
    7: {
        final: [
            { question: "Which of the following best explains why trimming a video clip is important in editing?", options: ["To increase the video file size", "To remove unwanted parts and keep only important scenes", "To add special effects to the video", "To change the video’s aspect ratio"], correctAnswer: "B" },
            { question: "Why is sequencing video clips properly crucial in storytelling?", options: ["It reduces the video’s resolution", "It ensures the story flows logically and is easy to understand", "It allows you to add more filters", "It increases the number of voice-overs"], correctAnswer: "B" },
            { question: "Which editing task would you perform to blend one video clip smoothly into the next?", options: ["Trimming", "Adding a transition", "Overlaying text", "Cropping"], correctAnswer: "B" },
            { question: "You are editing a video and want to label a person speaking. Which tool will you most likely use?", options: ["Audio Track", "Title/Text Overlay", "Transition Effect", "Cut Tool"], correctAnswer: "B" },
            { question: "A classmate exported a video with poor visual quality. Which setting should they adjust to fix this?", options: ["Reduce file format size", "Change to a higher resolution (e.g., 1080p)", "Add more text overlays", "Insert background music"], correctAnswer: "B" },
            { question: "What is the primary purpose of a timeline in video editing software?", options: ["To play music in the background", "To arrange and organize video clips in order", "To increase the video speed", "To save the final video project"], correctAnswer: "B" },
            { question: "Which of the following scenarios best demonstrates the use of a voice-over?", options: ["Adding a soundtrack to a video montage", "Narrating information while a video plays in the background", "Inserting text captions for viewers to read", "Using a fade-in transition at the beginning of a video"], correctAnswer: "B" },
            { question: "You want to focus on a small object in your video. Which editing technique is most appropriate?", options: ["Trimming the video", "Applying a zoom-in effect", "Adding a text overlay", "Changing the video aspect ratio"], correctAnswer: "B" },
            { question: "A student applies a slow-motion effect. Which editing purpose does this serve?", options: ["To make the video file larger", "To emphasize a specific moment or action", "To change the video file format", "To adjust the audio volume"], correctAnswer: "B" },
            { question: "Which of the following explains why exporting is the final step in video editing?", options: ["It makes the video editable again", "It saves the edited video into a playable file format", "It deletes unnecessary clips", "It adjusts the brightness of the video"], correctAnswer: "B" },
            { question: "A student added too many special effects and their video became distracting. What concept should they consider?", options: ["Balancing visual elements for clarity and focus", "Adding more sound effects to match the visuals", "Increasing the number of clips on the timeline", "Using a lower resolution to reduce file size"], correctAnswer: "A" },
            { question: "How does aspect ratio affect how a video is viewed?", options: ["It determines how many clips can be placed on the timeline", "It changes the proportion of width and height of the video frame", "It reduces the background noise", "It speeds up video rendering time"], correctAnswer: "B" },
            { question: "You added a text overlay but it blocks important visuals in your video. What should you do?", options: ["Increase the font size for emphasis", "Change the text position or make it semi-transparent", "Add a louder sound effect", "Export the video immediately"], correctAnswer: "B" },
            { question: "What happens if clips are not arranged logically on the timeline?", options: ["The video will automatically fix the sequence", "The video’s story will be confusing and unclear", "The export process will be faster", "Transitions will automatically adjust"], correctAnswer: "B" },
            { question: "A classmate wants to remove the background noise in a video. Which part of editing should they focus on?", options: ["Video timeline arrangement", "Audio track adjustments and enhancements", "Trimming the video clips", "Changing the aspect ratio"], correctAnswer: "B" },
            { question: "When is it appropriate to use a fade-out transition effect?", options: ["To introduce a new video clip suddenly", "To smoothly end a video scene or project", "To add more text overlays", "To enhance audio clarity"], correctAnswer: "B" },
            { question: "A student wants their school project video to look brighter and more vibrant. What editing process should they apply?", options: ["Add more clips to the timeline", "Adjust color correction or apply visual filters", "Insert voice-over narration", "Cut the video into smaller clips"], correctAnswer: "B" },
            { question: "Which scenario best describes the misuse of video editing tools?", options: ["Using a filter to enhance a dull video", "Adding multiple soundtracks that overlap and create noise", "Trimming unnecessary video parts for better flow", "Adding text to label key information"], correctAnswer: "B" },
            { question: "A student finishes editing but saves the project file only (e.g., .prproj). What mistake did they make?", options: ["They did not add enough transitions", "They forgot to export/render the final video into a playable format", "They didn’t apply any color correction", "They arranged clips incorrectly"], correctAnswer: "B" },
            { question: "Why is previewing the video before exporting an important step?", options: ["To check for editing mistakes and ensure smooth playback", "To save time by exporting early", "To delete the audio tracks quickly", "To reduce the resolution for faster upload"], correctAnswer: "A" }
        ]
    }
};

function RealtimeClock() {
  const [currentDateTime, setCurrentDateTime] = useState(new Date());

  useEffect(() => {
    const timerId = setInterval(() => setCurrentDateTime(new Date()), 1000);
    return () => clearInterval(timerId);
  }, []);

  const options: Intl.DateTimeFormatOptions = {
    weekday: 'long',
    year: 'numeric',
    month: 'long',
    day: 'numeric',
  };

  return (
    <div className="realtime-clock">
      <p>
        {currentDateTime.toLocaleDateString('en-US', options)} | {currentDateTime.toLocaleTimeString('en-US')}
      </p>
    </div>
  );
}

function ProgressBar({ progress }: { progress: number }) {
  return (
    <div className="progress-bar-container" aria-label={`Progress: ${progress}%`}>
      <div className="progress-bar-fill" style={{ width: `${progress}%` }}></div>
      <span className="progress-text">{progress}%</span>
    </div>
  );
}

function App() {
  const [showCourses, setShowCourses] = useState(false);
  const [courses, setCourses] = useState<CourseWithState[]>(() => {
    try {
        const savedProgressJSON = localStorage.getItem('courseProgress');
        if (savedProgressJSON) {
            const savedData = JSON.parse(savedProgressJSON);
            const savedCourses = savedData.courses as CourseWithState[];
            const savedCoursesMap = new Map(savedCourses.map(c => [c.id, c]));

            let finalCourses = initialCourses.map(initialCourse => {
                const savedCourse = savedCoursesMap.get(initialCourse.id);
                if (savedCourse) {
                    return { ...savedCourse, description: initialCourse.description, title: initialCourse.title };
                }
                return { ...initialCourse, progress: 0, status: 'locked' as const };
            });

            for (let i = 1; i < finalCourses.length; i++) {
                if (finalCourses[i - 1].status === 'completed' && finalCourses[i].status === 'locked') {
                    finalCourses[i].status = 'unlocked';
                }
            }
            return finalCourses;
        }
    } catch (error) {
        console.error("Could not load course progress from localStorage:", error);
    }
    
    return initialCourses.map((course) => ({
      ...course,
      progress: 0,
      status: 'locked',
    }));
  });
  const [selectedCourse, setSelectedCourse] = useState<CourseWithState | null>(null);
  const [isGeneratingPDF, setIsGeneratingPDF] = useState(false);

  // Course 4 State
  const [course4Topics, setCourse4Topics] = useState<CourseTopic[]>(() => {
    try {
        const savedProgressJSON = localStorage.getItem('courseProgress');
        if (savedProgressJSON) {
            const savedData = JSON.parse(savedProgressJSON);
            if(savedData.course4Topics) {
              return savedData.course4Topics;
            }
        }
    } catch (error) {
        console.error("Could not load Course 4 topics from localStorage:", error);
    }
    return initialCourse4Topics;
  });
  const [selectedCourse4Topic, setSelectedCourse4Topic] = useState<string | null>(null);
  
  // Quiz State
  const [activeQuizPart, setActiveQuizPart] = useState<string | null>(null);
  const [userAnswers, setUserAnswers] = useState<{ [key: number]: string }>({});
  const [quizResult, setQuizResult] = useState<{ score: number; total: number; passed: boolean; part: string } | null>(null);
  
  // Teacher Unlock State
  const [unlockCodeInputs, setUnlockCodeInputs] = useState<{ [key: number]: string }>({});
  const [unlockError, setUnlockError] = useState<{ [key: number]: string | null }>({});

  // Disclaimer Modal State
  const [isDisclaimerVisible, setIsDisclaimerVisible] = useState(false);
  const [videoUrlToOpen, setVideoUrlToOpen] = useState<string | null>(null);

  // Main Page Video Disclaimer State
  const [hasWatchedDisclaimerVideo, setHasWatchedDisclaimerVideo] = useState(false);

  const handleVideoLinkClick = (e: React.MouseEvent, url: string) => {
      e.preventDefault();
      setVideoUrlToOpen(url);
      setIsDisclaimerVisible(true);
  };
  
  const handleAcceptDisclaimer = () => {
      if (videoUrlToOpen) {
          window.open(videoUrlToOpen, '_blank', 'noopener,noreferrer');
      }
      setVideoUrlToOpen(null);
      setIsDisclaimerVisible(false);
  };
  
  const handleCancelDisclaimer = () => {
      setVideoUrlToOpen(null);
      setIsDisclaimerVisible(false);
  };

  const VideoLink = ({ href, children }: { href: string; children: React.ReactNode }) => (
    <a href={href} target="_blank" rel="noopener noreferrer" onClick={(e) => handleVideoLinkClick(e, href)}>
        {children}
    </a>
  );
  
  const activeCourse1Content = course1Content(VideoLink);
  const activeCourse4TopicContent = course4TopicContent(VideoLink);

  useEffect(() => {
    try {
        const dataToSave = {
            courses,
            course4Topics
        };
        localStorage.setItem('courseProgress', JSON.stringify(dataToSave));
    } catch (error) {
        console.error("Could not save progress automatically:", error);
    }
  }, [courses, course4Topics]);
  
  const handleStartCourse = () => setShowCourses(true);
  const handleGoBack = () => setShowCourses(false);

  const handleWatchConfirmation = () => {
    setHasWatchedDisclaimerVideo(true);
  };

  const handleViewCourse = (course: CourseWithState) => {
    if (course.status !== 'locked') {
      setSelectedCourse(course);
      setActiveQuizPart(null);
      setUserAnswers({});
      setQuizResult(null);
      if (course.id === 4) {
        setSelectedCourse4Topic(null);
      }
    }
  };

  const handleGoBackFromDetail = () => {
    setSelectedCourse(null);
    setSelectedCourse4Topic(null);
  }
  
  const handleDownloadPDF = async () => {
    const contentToPrint = document.querySelector('.course-detail-content');
    const courseTitle = selectedCourse?.title;
    if (!contentToPrint || !courseTitle) return;

    setIsGeneratingPDF(true);
    contentToPrint.classList.add('pdf-render-mode');
    try {
        const canvas = await html2canvas(contentToPrint as HTMLElement, { scale: 2, useCORS: true });
        contentToPrint.classList.remove('pdf-render-mode');
        const imgData = canvas.toDataURL('image/png');
        const pdf = new jsPDF('p', 'mm', 'a4');
        const pdfWidth = pdf.internal.pageSize.getWidth();
        const pdfHeight = pdf.internal.pageSize.getHeight();
        const imgProps= pdf.getImageProperties(imgData);
        const ratio = imgProps.height / imgProps.width;
        const imgWidth = pdfWidth - 20;
        const imgHeight = imgWidth * ratio;
        let heightLeft = imgHeight;
        let position = 10;
        pdf.addImage(imgData, 'PNG', 10, position, imgWidth, imgHeight);
        heightLeft -= (pdfHeight - 20);
        while (heightLeft > 0) {
            position -= (pdfHeight - 20);
            pdf.addPage();
            pdf.addImage(imgData, 'PNG', 10, position, imgWidth, imgHeight);
            heightLeft -= (pdfHeight - 20);
        }
        pdf.save(`${courseTitle.replace(/[^a-zA-Z0-9]/g, '_')}.pdf`);
    } catch (error) {
        console.error("Error generating PDF:", error);
        alert("Sorry, there was an error creating the PDF. Please try again.");
    } finally {
        setIsGeneratingPDF(false);
    }
  };
  
  const handleNextCourse = () => {
      if (!selectedCourse) return;
      const currentCourseIndex = courses.findIndex(c => c.id === selectedCourse.id);
      const nextCourse = courses[currentCourseIndex + 1];
      if (nextCourse && nextCourse.status !== 'locked') {
          handleViewCourse(nextCourse);
      } else {
          handleGoBackFromDetail();
      }
  };
  
  // --- Teacher Unlock Functions ---
  const handleUnlockCodeChange = (courseId: number, value: string) => {
    setUnlockCodeInputs(prev => ({ ...prev, [courseId]: value }));
    if (unlockError[courseId]) {
      setUnlockError(prev => ({ ...prev, [courseId]: null }));
    }
  };

  const handleUnlockAttempt = (courseId: number) => {
    const enteredCode = unlockCodeInputs[courseId];
    const correctCode = unlockCodes[courseId];

    if (enteredCode === correctCode) {
      const updatedCourses = courses.map(c => {
        if (c.id === courseId) {
          return { ...c, status: 'unlocked' as const };
        }
        return c;
      });
      setCourses(updatedCourses);
      setUnlockError(prev => ({ ...prev, [courseId]: null }));
    } else {
      setUnlockError(prev => ({ ...prev, [courseId]: 'Incorrect code. Please try again.' }));
    }
  };

  // --- Quiz Functions ---
  const handleStartQuiz = (part: string) => {
    setActiveQuizPart(part);
    setUserAnswers({});
    setQuizResult(null);
  };
  
  const handleAnswerChange = (questionIndex: number, answer: string) => {
    setUserAnswers(prev => ({ ...prev, [questionIndex]: answer }));
  };

  const handleQuizSubmit = () => {
    if (!selectedCourse || !activeQuizPart) return;

    if (selectedCourse.id === 4) {
        const currentQuizData = quizzes[4]?.[activeQuizPart];
        if (!currentQuizData) return;
        
        let score = 0;
        currentQuizData.forEach((q, index) => {
            if (userAnswers[index] === q.correctAnswer) {
                score++;
            }
        });

        const passed = score >= 3;

        if (passed) {
            const updatedTopics: CourseTopic[] = course4Topics.map(t => t.id === activeQuizPart ? { ...t, status: 'completed' } : t);
            const currentTopicIndex = updatedTopics.findIndex(t => t.id === activeQuizPart);

            if (currentTopicIndex + 1 < updatedTopics.length) {
                updatedTopics[currentTopicIndex + 1].status = 'unlocked';
            }
            setCourse4Topics(updatedTopics);

            const completedCount = updatedTopics.filter(t => t.status === 'completed').length;
            const newProgress = Math.round((completedCount / updatedTopics.length) * 100);

            let updatedCourses = courses.map(c => c.id === 4 ? { ...c, progress: newProgress } : c);

            if (completedCount === updatedTopics.length) {
                updatedCourses = updatedCourses.map(c => c.id === 4 ? { ...c, status: 'completed' } : c);
                const nextCourseIndex = updatedCourses.findIndex(c => c.id === 4) + 1;
                if (nextCourseIndex < updatedCourses.length) {
                    updatedCourses[nextCourseIndex].status = 'unlocked';
                }
            }
            setCourses(updatedCourses);
            setSelectedCourse(prev => prev ? updatedCourses.find(c => c.id === prev.id) || null : null);
        }
        
        setQuizResult({ score, total: currentQuizData.length, passed, part: activeQuizPart });
        setActiveQuizPart(null);
        return;
    }

    const currentQuizData = quizzes[selectedCourse.id]?.[activeQuizPart];
    if (!currentQuizData) return;
    
    let score = 0;
    currentQuizData.forEach((q, index) => {
      if (userAnswers[index] === q.correctAnswer) {
        score++;
      }
    });
    
    let passed = false;
    let finalAssessment = activeQuizPart === 'final';

    if (finalAssessment) {
        let passingScore = 0;
        if (selectedCourse.id === 1) {
            passingScore = 9;
        } else if (selectedCourse.id === 2) {
            passingScore = 12;
        } else if (selectedCourse.id === 3) {
            passingScore = 12;
        } else {
            passingScore = Math.ceil(currentQuizData.length * 0.75);
        }
        passed = score >= passingScore;

        if (passed) {
             const updatedCourses = courses.map(c => {
                if (c.id === selectedCourse.id) {
                  return { ...c, progress: 100, status: 'completed' as const };
                }
                return c;
            });

            const currentCourseIndex = updatedCourses.findIndex(c => c.id === selectedCourse.id);
            const nextCourseIndex = currentCourseIndex + 1;
            if (nextCourseIndex < updatedCourses.length && updatedCourses[nextCourseIndex].status === 'locked') {
                updatedCourses[nextCourseIndex].status = 'unlocked';
            }
      
            setCourses(updatedCourses);
            setSelectedCourse(prev => prev ? updatedCourses.find(c => c.id === prev.id) || null : null);
        }
    } else {
        let passingScore = Math.ceil(currentQuizData.length * 0.75);
        if (selectedCourse.id === 1 && activeQuizPart === 'part1') passingScore = 3;
        
        passed = score >= passingScore;

        if (passed) {
          const updatedCourses = courses.map(c => {
            if (c.id === selectedCourse.id) {
              let newProgress = c.progress;
              if (selectedCourse.id === 1) {
                  newProgress = activeQuizPart === 'part1' ? 33 : 66; 
              }
              return { ...c, progress: newProgress };
            }
            return c;
          });
          
          setCourses(updatedCourses);
          setSelectedCourse(prev => prev ? updatedCourses.find(c => c.id === prev.id) || null : null);
        }
    }

    setQuizResult({ score, total: currentQuizData.length, passed, part: activeQuizPart });
    setActiveQuizPart(null);
  };
  
  const handleTryAgain = () => {
    if (quizResult) {
      handleStartQuiz(quizResult.part);
    }
  };
  
  const handleReviewCourse = () => {
    setQuizResult(null);
  };

  const handleProceed = () => {
    setQuizResult(null);
    if(selectedCourse?.id === 4) {
      setSelectedCourse4Topic(null);
    }
  }

  // --- Render Functions ---
  const renderQuizContent = () => {
    if (!selectedCourse || !activeQuizPart) return null;
    const quizData = selectedCourse.id === 4
        ? quizzes[4]?.[activeQuizPart]
        : quizzes[selectedCourse.id]?.[activeQuizPart];
    if (!quizData || quizData.length === 0) return null;

    let passingScoreText = '';
    if (selectedCourse.id === 4) {
        passingScoreText = `You need to score at least 3 out of ${quizData.length} to pass this topic.`;
    } else if (activeQuizPart === 'final') {
        let passingNum = 0;
        if (selectedCourse.id === 1) {
            passingNum = 9;
        } else if (selectedCourse.id === 2) {
            passingNum = 12;
        } else if (selectedCourse.id === 3) {
            passingNum = 12;
        } else {
            passingNum = Math.ceil(quizData.length * 0.75);
        }
        passingScoreText = `You need to score at least ${passingNum} out of ${quizData.length} to pass this course.`;
    } else {
        const passingNum = Math.ceil(quizData.length * 0.75);
        passingScoreText = `Answer at least ${passingNum} correctly to proceed.`;
    }


    return (
        <div className="quiz-container">
            <h3>{selectedCourse.id === 4 ? `Quiz: ${course4Topics.find(t=>t.id === activeQuizPart)?.title}` : (activeQuizPart === 'final' ? 'Course Assessment' : `Topic Quiz (Part ${activeQuizPart.replace('part', '')})`)}</h3>
            <p className="quiz-instruction">
              {passingScoreText}
            </p>
            {quizData.map((q, index) => (
                <div key={index} className="quiz-question-container">
                    <p className="quiz-question-text">{index + 1}. {q.question}</p>
                    <div className="quiz-options">
                        {q.options.map((option:string, i:number) => {
                            const optionLetter = String.fromCharCode(65 + i);
                            return (
                                <label key={i}>
                                    <input type="radio" name={`question-${index}`} value={optionLetter} checked={userAnswers[index] === optionLetter} onChange={() => handleAnswerChange(index, optionLetter)} />
                                    <span>{optionLetter}. {option}</span>
                                </label>
                            );
                        })}
                    </div>
                </div>
            ))}
            <button className="btn" onClick={handleQuizSubmit}>Submit Answers</button>
        </div>
    );
  };
  
  const renderQuizResult = () => {
    if (!quizResult) return null;
    
    if (selectedCourse?.id === 4) {
        const currentTopic = course4Topics.find(t => t.id === quizResult.part);
        const nextTopic = course4Topics[course4Topics.findIndex(t => t.id === quizResult.part) + 1];
        const isFinalTopic = !nextTopic;

        return (
            <div className={`quiz-result-container ${quizResult.passed ? 'pass' : 'fail'}`}>
                <h3>{quizResult.passed ? 'Topic Passed!' : 'Needs Review'}</h3>
                <p className="quiz-score">{quizResult.score} / {quizResult.total}</p>
                <p className="quiz-result-message">
                    {quizResult.passed ?
                        `You have successfully passed the quiz for ${currentTopic?.title}.` :
                        `You needed 3 correct answers to pass. Please review the topic and try again.`
                    }
                </p>
                <div className="quiz-result-actions">
                    {quizResult.passed ? (
                        isFinalTopic ? (
                             <button className="btn" onClick={handleGoBackFromDetail}>Back to Courses</button>
                        ) : (
                             <button className="btn" onClick={handleProceed}>Continue to Next Topic</button>
                        )
                    ) : (
                        <>
                            <button className="btn btn-secondary" onClick={() => setQuizResult(null)}>Review Topic</button>
                            <button className="btn" onClick={handleTryAgain}>Try Quiz Again</button>
                        </>
                    )}
                </div>
            </div>
        )
    }

    if (quizResult.part === 'final') {
        let passingNum = 0;
        if (selectedCourse.id === 1) {
            passingNum = 9;
        } else if (selectedCourse.id === 2) {
            passingNum = 12;
        } else if (selectedCourse.id === 3) {
            passingNum = 12;
        } else if (quizzes[selectedCourse.id]?.[quizResult.part]) {
            passingNum = Math.ceil(quizzes[selectedCourse.id][quizResult.part].length * 0.75);
        }

        return (
             <div className={`quiz-result-container ${quizResult.passed ? 'pass' : 'fail'}`}>
                <h3>{quizResult.passed ? 'Congratulations! Course Passed!' : 'Assessment Failed'}</h3>
                <p className="quiz-score">{quizResult.score} / {quizResult.total}</p>
                <p className="quiz-result-message">
                    {quizResult.passed ? 'You have successfully passed the assessment and completed this course.' : `You needed ${passingNum} correct answers to pass. Please review the course material and try again.`}
                </p>
                <div className="quiz-result-actions">
                    {quizResult.passed ? (
                         <button className="btn" onClick={handleNextCourse}>Proceed to Next Course</button>
                    ) : (
                        <>
                            <button className="btn btn-secondary" onClick={handleReviewCourse}>Review Course</button>
                            <button className="btn" onClick={handleTryAgain}>Try Assessment Again</button>
                        </>
                    )}
                </div>
            </div>
        )
    }

    const passingScore = Math.ceil(quizzes[selectedCourse.id][quizResult.part].length * 0.75);
    const partNum = parseInt(quizResult.part.replace('part', ''), 10);
    return (
        <div className={`quiz-result-container ${quizResult.passed ? 'pass' : 'fail'}`}>
            <h3>{quizResult.passed ? 'Great Job!' : 'Needs Review'}</h3>
            <p className="quiz-score">{quizResult.score} / {quizResult.total}</p>
            <p className="quiz-result-message">
                {quizResult.passed ? 'You passed this section. You can now proceed.' : `You need at least ${passingScore} correct answer(s) to pass. Please review the material and try again.`}
            </p>
            <div className="quiz-result-actions">
                {quizResult.passed ? (
                     <button className="btn" onClick={handleProceed}>Continue to Topic {partNum + 1}</button>
                ) : (
                    <button className="btn btn-secondary" onClick={handleTryAgain}>Try Again</button>
                )}
            </div>
        </div>
    );
  }

  const renderVideoDisclaimerModal = () => (
    <div className="disclaimer-overlay">
        <div className="disclaimer-modal">
            <h3>Video Content Disclaimer</h3>
            <p>
                You are about to view a video on an external website (e.g., YouTube). Please be aware that:
            </p>
            <ul>
                <li>The content is not hosted on this platform.</li>
                <li>The external site may have different privacy policies and terms of use.</li>
                <li>Parental guidance is advised for all external content.</li>
            </ul>
            <p>Do you wish to proceed?</p>
            <div className="disclaimer-actions">
                <button className="btn btn-secondary" onClick={handleCancelDisclaimer}>Cancel</button>
                <button className="btn" onClick={handleAcceptDisclaimer}>Proceed to Video</button>
            </div>
        </div>
    </div>
  );

  if (selectedCourse) {
    const isCourseComplete = selectedCourse.status === 'completed';
    const currentCourseIndex = courses.findIndex(c => c.id === selectedCourse.id);
    const isNextCourseAvailable = currentCourseIndex < courses.length - 1;
    const isCourse1 = selectedCourse.id === 1;
    const isCourse4 = selectedCourse.id === 4;

    return (
      <div className="app-container">
        {isDisclaimerVisible && renderVideoDisclaimerModal()}
        {isGeneratingPDF && (
            <div className="pdf-loading-overlay">
                <div className="spinner"></div>
                <p>Generating PDF, please wait...</p>
            </div>
        )}
        <div className="course-detail-view">
          <header className="course-detail-header">
            <h2>{selectedCourse.title}</h2>
          </header>
          <main className="course-detail-content">
             {isCourse1 ? (
                <>
                    {activeCourse1Content.part1}
                    {selectedCourse.progress < 33 && !isCourseComplete && !activeQuizPart && !quizResult &&(
                        <div className="start-quiz-container">
                            <button className="btn" onClick={() => handleStartQuiz('part1')}>Answer follow-up questions to proceed</button>
                        </div>
                    )}

                    <div className={`part-content-wrapper ${selectedCourse.progress < 33 && !isCourseComplete ? 'content-locked' : ''}`}>
                         <div className="course-discussion-content part-2">
                            {activeCourse1Content.part2}
                         </div>
                         {selectedCourse.progress >= 33 && selectedCourse.progress < 66 && !isCourseComplete && !activeQuizPart && !quizResult &&(
                            <div className="start-quiz-container">
                                <button className="btn" onClick={() => handleStartQuiz('part2')}>Answer Follow-up Questions</button>
                            </div>
                        )}
                    </div>
                    
                    <div className={`part-content-wrapper ${selectedCourse.progress < 66 && !isCourseComplete ? 'content-locked' : ''}`}>
                        <div className="course-discussion-content part-3">
                            {activeCourse1Content.part3}
                        </div>
                        {selectedCourse.progress >= 66 && !isCourseComplete && !activeQuizPart && !quizResult &&(
                            <div className="course-completion-container">
                                <button className="btn btn-assessment" onClick={() => handleStartQuiz('final')}>Take Course Assessment</button>
                            </div>
                        )}
                    </div>

                    {activeQuizPart && renderQuizContent()}
                    {quizResult && renderQuizResult()}

                    {isCourseComplete && (
                         <div className="quiz-result-container pass">
                           <h3><span className="completed-icon" aria-label="completed">✔️</span> Course Completed</h3>
                           <p className="quiz-result-message">You have successfully completed this course.</p>
                            <div className="quiz-result-actions">
                               {isNextCourseAvailable && <button className="btn" onClick={handleNextCourse}>Next Course</button>}
                           </div>
                         </div>
                    )}
                </>
             ) : isCourse4 ? (
                <>
                  {selectedCourse4Topic && !activeQuizPart && !quizResult ? (
                      <>
                          {activeCourse4TopicContent[selectedCourse4Topic]}
                          {course4Topics.find(t => t.id === selectedCourse4Topic)?.status === 'completed' ? (
                            <div className="quiz-result-container pass" style={{marginTop: '2rem', paddingTop: '2rem', paddingBottom: '2rem'}}>
                                <h3><span className="completed-icon" aria-label="completed">✔️</span> Topic Completed</h3>
                                <p>You have already passed the quiz for this topic.</p>
                            </div>
                          ) : (
                              <div className="start-quiz-container">
                                  <button className="btn" onClick={() => handleStartQuiz(selectedCourse4Topic)}>Take Quiz</button>
                              </div>
                          )}
                          <div className="topic-navigation">
                              <button className="btn btn-secondary" onClick={() => setSelectedCourse4Topic(null)}>Back to Topics</button>
                          </div>
                      </>
                  ) : activeQuizPart ? (
                      renderQuizContent()
                  ) : quizResult ? (
                      renderQuizResult()
                  ) : (
                      <>
                          <div className="course-discussion-content">
                              <h4>Topics</h4>
                              <p>This chapter provides an overview of the essential hardware and software tools used across different fields of Information and Communications Technology. Complete the topics in order to finish the chapter.</p>
                              <div className="course-topic-buttons">
                                {course4Topics.map(topic => (
                                    <button 
                                      key={topic.id}
                                      className={`btn btn-topic ${topic.status}`} 
                                      onClick={() => setSelectedCourse4Topic(topic.id)}
                                      disabled={topic.status === 'locked'}
                                    >
                                      {topic.title}
                                      {topic.status === 'locked' && <span className="lock-icon" aria-label="locked">🔒</span>}
                                      {topic.status === 'completed' && <span className="completed-icon" aria-label="completed">✔️</span>}
                                    </button>
                                ))}
                              </div>
                          </div>
                          {isCourseComplete && (
                              <div className="quiz-container quiz-result-container pass">
                                <h3><span className="completed-icon" aria-label="completed">✔️</span> Course Completed</h3>
                                <p className="quiz-result-message">You have successfully completed this course.</p>
                                 <div className="quiz-result-actions">
                                    {isNextCourseAvailable && <button className="btn" onClick={handleNextCourse}>Next Course</button>}
                                </div>
                              </div>
                           )}
                      </>
                  )}
                </>
             ) : (
                <>
                    {activeQuizPart && renderQuizContent()}
                    {quizResult && renderQuizResult()}

                    {!activeQuizPart && !quizResult && (
                        <>
                            {courseDiscussions[selectedCourse.id]}
                            {isCourseComplete ? (
                                <div className="quiz-container quiz-result-container pass">
                                  <h3><span className="completed-icon" aria-label="completed">✔️</span> Course Completed</h3>
                                  <p className="quiz-result-message">You have successfully completed this course.</p>
                                   <div className="quiz-result-actions">
                                      {isNextCourseAvailable && <button className="btn" onClick={handleNextCourse}>Next Course</button>}
                                  </div>
                                </div>
                            ) : (
                                quizzes[selectedCourse.id]?.final ? (
                                    <div className="course-completion-container">
                                        <button className="btn btn-assessment" onClick={() => handleStartQuiz('final')}>Take Course Assessment</button>
                                    </div>
                                ) : (
                                    <div className="course-completion-container">
                                        {/* This button is for courses without quizzes or special logic */}
                                    </div>
                                )
                            )}
                        </>
                    )}
                </>
             )}
          </main>
          <footer className="course-detail-footer">
            <button className="btn btn-secondary" onClick={handleGoBackFromDetail}>Back to Courses</button>
            <div className="course-detail-footer-actions">
              <button className="btn" onClick={handleDownloadPDF} disabled={isGeneratingPDF}>
                {isGeneratingPDF ? 'Generating...' : 'Download as PDF'}
              </button>
            </div>
          </footer>
        </div>
      </div>
    );
  }

  if (showCourses) {
    return (
      <div className="app-container">
        {isDisclaimerVisible && renderVideoDisclaimerModal()}
        <section>
          <div className="course-list-header">
            <h2>Your Learning Path</h2>
            <div className="course-list-actions">
              <button className="btn btn-secondary" onClick={handleGoBack}>Go Back</button>
            </div>
          </div>
          <div className="course-grid">
             {courses.length === 0 ? (
                <div className="empty-state-message">
                  <p>There are no courses available at this time.</p>
                  <p>Please check back later!</p>
                </div>
              ) : courses.map(course => (
              <article key={course.id} className={`course-card ${course.status}`} aria-label={`${course.title} - ${course.status}`}>
                <div className="course-card-content">
                  <h3>
                    {course.title}
                    {course.status === 'locked' && <span className="lock-icon" aria-label="locked">🔒</span>}
                  </h3>
                  <p className="course-card-description">{course.description}</p>
                  <ProgressBar progress={course.progress} />
                </div>
                 <div className="course-card-actions">
                    {course.status === 'locked' && unlockCodes[course.id] && (
                        <div className="unlock-form-container">
                            <input
                                type="password"
                                placeholder="Teacher's Code"
                                value={unlockCodeInputs[course.id] || ''}
                                onChange={(e) => handleUnlockCodeChange(course.id, e.target.value)}
                                onKeyDown={(e) => e.key === 'Enter' && handleUnlockAttempt(course.id)}
                                aria-label={`Unlock code for ${course.title}`}
                            />
                            <button 
                                className="btn btn-unlock" 
                                onClick={() => handleUnlockAttempt(course.id)}
                                aria-label={`Unlock ${course.title}`}
                            >
                                Unlock
                            </button>
                            {unlockError[course.id] && <p className="unlock-error-message">{unlockError[course.id]}</p>}
                        </div>
                    )}
                    <button 
                      className="btn" 
                      onClick={() => handleViewCourse(course)}
                      disabled={course.status === 'locked'}
                    >
                      {course.status === 'completed' ? 'Review Course' : (course.progress > 0 ? 'Continue Course' : 'Start Course')}
                    </button>
                 </div>
              </article>
            ))}
          </div>
        </section>
      </div>
    );
  }

  return (
    <div className="app-container">
      {isDisclaimerVisible && renderVideoDisclaimerModal()}
      <header>
        <img src="https://i.imgur.com/BCrtgB0.png" alt="Guinsiliban National High School Logo" className="school-logo" />
        <h1 className="logo">Grade 8 TLE-ICT Learning Management Support System</h1>
        <div className="developer-info">
          <p>Developed By: CLOYD MARK M CABUSOG</p>
          <p>Guinsiliban National High School</p>
        </div>
      </header>
      <main>
        <div className="welcome-section">
          <div className="welcome-content">
            <h2>Welcome, Future ICT Expert!</h2>
            <p className="subtitle">Empowering Technology and Livelihood Education</p>
            <p className="greeting">Hello, Grade 8 Learners!</p>
            <p>Welcome to your digital classroom for TLE-ICT. This learning system is designed to guide you through the exciting world of Information and Communications Technology. Here, you'll explore everything from digital marketing to cybersecurity, all at your own pace.</p>
            <p>Each course builds on the last, unlocking new skills and knowledge. Complete lessons, pass quizzes, and watch your progress grow. Let's get started on this journey to become tech-savvy and responsible digital citizens!</p>
            
            <div className="video-disclaimer-section">
                <h4><span className="required-star">*</span> Important: Please Watch Before Starting</h4>
                <p>Please watch the following video disclaimer in its entirety before proceeding to the courses.</p>
                <div className="video-container">
                    <video
                        src="https://i.imgur.com/K5ySVFA.mp4"
                        title="Video Disclaimer"
                        controls
                        playsInline
                    >
                        Sorry, your browser doesn't support embedded videos.
                    </video>
                </div>
                <button 
                    className="btn btn-secondary" 
                    onClick={handleWatchConfirmation}
                    disabled={hasWatchedDisclaimerVideo}
                >
                    {hasWatchedDisclaimerVideo ? '✔️ Watched' : "I Have Watched the Disclaimer"}
                </button>
            </div>
            
            <p className="call-to-action">Ready to begin your ICT adventure?</p>
            <div className="start-course-container">
              <button 
                className="btn" 
                onClick={handleStartCourse}
                disabled={!hasWatchedDisclaimerVideo}
                aria-describedby={!hasWatchedDisclaimerVideo ? "start-course-disabled-msg" : undefined}
              >
                Start Learning Now
              </button>
              {!hasWatchedDisclaimerVideo && (
                  <p id="start-course-disabled-msg" className="disabled-message">
                      (You must first confirm you have watched the video above)
                  </p>
              )}
            </div>
          </div>
          <div className="welcome-image-container">
            <img src="https://i.imgur.com/IknP7XN.png" alt="Students learning with technology illustration" className="welcome-image" />
          </div>
        </div>
      </main>
       <footer className="main-footer">
          <RealtimeClock />
          <p>
              Powered By GNHS&nbsp;
              <img src="https://media.quizizz.com/_mdserver/main/media/resource/gs/quizizz-media/quizzes/26ee3c2c-a205-4141-867f-6e886c78b795-v2" alt="Matatag Logo" className="matatag-logo" />
              &nbsp;Curriculum Implementation
          </p>
          <p>
            in cooperation with Guinsiliban National High School
            <a href="https://govdata.co.uk/frameworks/it-pillar/ict-hardware-and-peripherals-equipment/" target="_blank" rel="noopener noreferrer">
              <img 
                src="https://govdata.co.uk/wp-content/uploads/2024/01/230394-ICT-Hardware-Logo-Black-BG.png" 
                alt="ICT Hardware and Peripherals Equipment Logo" 
                className="cooperation-logo" 
              />
            </a>
          </p>
      </footer>
    </div>
  );
}

const container = document.getElementById('root');
const root = createRoot(container!);
root.render(<App />);